=== modified file 'HACKING'
--- HACKING	2006-10-13 07:22:23 +0000
+++ HACKING	2006-10-16 04:38:20 +0000
@@ -78,11 +78,58 @@
 There are some common requirements in the library: some parameters need to be
 unicode safe, some need byte strings, and so on. At the moment we have
 only codified one specific pattern: Parameters that need to be unicode
-should be checked via 'bzrlib.osutils.safe_unicode'. This will coerce the
+should be checked via ``bzrlib.osutils.safe_unicode``. This will coerce the
 input into unicode in a consistent fashion, allowing trivial strings to be
 used for programmer convenience, but not performing unpredictably in the
 presence of different locales.
 
+
+Copyright
+---------
+
+The copyright policy for bzr was recently made clear in this email (edited
+for grammatical correctness)::
+
+    The attached patch cleans up the copyright and license statements in
+    the bzr source. It also adds tests to help us remember to add them
+    with the correct text.
+
+    We had the problem that lots of our files were "Copyright Canonical
+    Development Ltd" which is not a real company, and some other variations
+    on this theme. Also, some files were missing the GPL statements.
+    
+    I want to be clear about the intent of this patch, since copyright can
+    be a little controversial.
+    
+    1) The big motivation for this is not to shut out the community, but
+    just to clean up all of the invalid copyright statements.
+    
+    2) It has been the general policy for bzr that we want a single
+    copyright holder for all of the core code. This is following the model
+    set by the FSF, which makes it easier to update the code to a new
+    license in case problems are encountered. (For example, if we want to
+    upgrade the project universally to GPL v3 it is much simpler if there is
+    a single copyright holder). It also makes it clearer if copyright is
+    ever debated, there is a single holder, which makes it easier to defend
+    in court, etc. (I think the FSF position is that if you assign them
+    copyright, they can defend it in court rather than you needing to, and
+    I'm sure Canonical would do the same).
+    As such, Canonical has requested copyright assignments from all of the
+    major contributers.
+    
+    3) If someone wants to add code and not attribute it to Canonical, there
+    is a specific list of files that are excluded from this check. And the
+    test failure indicates where that is, and how to update it.
+    
+    4) If anyone feels that I changed a copyright statement incorrectly, just
+    let me know, and I'll be happy to correct it. Whenever you have large
+    mechanical changes like this, it is possible to make some mistakes.
+    
+    Just to reiterate, this is a community project, and it is meant to stay
+    that way. Core bzr code is copyright Canonical for legal reasons, and
+    the tests are just there to help us maintain that.
+
+
 Documentation
 =============
 

=== modified file 'Makefile'
--- Makefile	2006-09-05 07:37:01 +0000
+++ Makefile	2006-10-16 06:38:32 +0000
@@ -1,7 +1,7 @@
 all:
 
 check:
-	./bzr selftest -v $(tests)
+	python -Werror ./bzr selftest -v $(tests)
 	@echo "Running all tests with no locale."
 	LC_CTYPE= LANG=C LC_ALL= ./bzr selftest -v $(tests)
 

=== modified file 'NEWS'
--- NEWS	2006-10-17 13:58:01 +0000
+++ NEWS	2006-10-17 14:01:12 +0000
@@ -5,6 +5,14 @@
     * urllib implements keep-alive connections and share them
       (Vincent Ladeuil, #53654)
 
+    * ``bzr log`` now shows dotted-decimal revision numbers for all revisions,
+      rather than just showing a decimal revision number for revisions on the
+      mainline. These revision numbers are not yet accepted as input into bzr
+      commands such as log, diff etc. (Robert Collins)
+
+    * revisions can now be specified using dotted-decimal revision numbers.
+      For instance, ``bzr diff -r 1.2.1..1.2.3. (Robert Collins)
+
     * ``bzr help commands`` output is now shorter (Aaron Bentley)
 
     * New connection: ``bzr+http://`` which supports tunnelling the smart
@@ -23,6 +31,11 @@
       to allow modules to be loaded on request. (John Arbash Meinel, Adeodato
       Simó)
 
+  API INCOMPATABILITY:
+  
+    * LogFormatter subclasses show now expect the 'revno' parameter to 
+      show() to be a string rather than an int. (Robert Collins)
+
   INTERNALS:
 
     * ``TestCase.run_bzr``, ``run_bzr_captured``, and ``run_bzr_subprocess``
@@ -37,6 +50,19 @@
       ``--no-plugins`` parameter to ensure test reproducability, and avoid
       problems with system-wide installed plugins. (John Arbash Meinel)
 
+    * Newly-initialized trees have unique root ids.  (Aaron Bentley)
+
+    * ``WorkingTree.set_root_id(None)`` is now deprecated. Please
+      pass in inventory.ROOT_ID if you want the default root id value.
+      (Robert Collins, John Arbash Meinel)
+
+    * New method ``WorkingTree.flush()`` which will write the current memory
+      inventory out to disk. At the same time, read_working_inventory will
+      no longer trash the current tree inventory if it has been modified within
+      the current lock, and the tree will now ``flush()`` automatically on
+      ``unlock()``. ``WorkingTree.set_root_id()`` has been updated to take
+      advantage of this functionality. (Robert Collins, John Arbash Meinel)
+
   BUG FIXES:
 
     * Give nicer error message when an http server returns a 403
@@ -239,6 +265,7 @@
       NoSuchFile and forcing the caller to repeat their request.
       (John Arbash Meinel)
 
+<<<<<<< TREE
     * WorkingTree has a new api ``unversion`` which allow the unversioning of
       entries by their file id. (Robert Collins)
 
@@ -290,6 +317,16 @@
       Transport. (Andrew Bennetts, Martin Pool)
 
 bzr 0.10  2006-08-29
+=======
+    * bzrlib.tsort.merge_sorted now accepts 'generate_revnos'. This parameter
+      will cause it to add another column to its output, which contains the
+      dotted-decimal revno for each revision, as a tuple. (Robert Collins)
+
+    * LogFormatter.show_merge is deprecated in favour of
+      LogFormatter.show_merge_revno. (Robert Collins)
+
+bzr 0.10.0RC1  2006-08-28
+>>>>>>> MERGE-SOURCE
   
   IMPROVEMENTS:
     * 'merge' now takes --uncommitted, to apply uncommitted changes from a

=== modified file 'bzr'
--- bzr	2006-10-11 00:23:23 +0000
+++ bzr	2006-10-16 01:25:46 +0000
@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/__init__.py'
--- bzrlib/__init__.py	2006-09-25 00:03:15 +0000
+++ bzrlib/__init__.py	2006-10-16 01:47:43 +0000
@@ -1,15 +1,15 @@
-# Copyright (C) 2005, 2006 Canonical Development Ltd
-
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

=== modified file 'bzrlib/annotate.py'
--- bzrlib/annotate.py	2006-09-29 20:24:37 +0000
+++ bzrlib/annotate.py	2006-10-16 01:25:46 +0000
@@ -1,15 +1,15 @@
-# Copyright (C) 2004, 2005 by Canonical Ltd
-
+# Copyright (C) 2004, 2005 Canonical Ltd
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

=== modified file 'bzrlib/atomicfile.py'
--- bzrlib/atomicfile.py	2006-09-13 02:51:49 +0000
+++ bzrlib/atomicfile.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005 by Canonical Ltd
+# Copyright (C) 2004, 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/benchmarks/__init__.py'
--- bzrlib/benchmarks/__init__.py	2006-10-10 06:28:41 +0000
+++ bzrlib/benchmarks/__init__.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/benchmarks/bench_add.py'
--- bzrlib/benchmarks/bench_add.py	2006-08-14 23:49:01 +0000
+++ bzrlib/benchmarks/bench_add.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_bench.py'
--- bzrlib/benchmarks/bench_bench.py	2006-09-05 21:25:15 +0000
+++ bzrlib/benchmarks/bench_bench.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_bundle.py'
--- bzrlib/benchmarks/bench_bundle.py	2006-10-04 10:17:53 +0000
+++ bzrlib/benchmarks/bench_bundle.py	2006-10-16 01:25:46 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_cache_utf8.py'
--- bzrlib/benchmarks/bench_cache_utf8.py	2006-08-10 00:43:37 +0000
+++ bzrlib/benchmarks/bench_cache_utf8.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,6 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+
 """Tests for encoding performance."""
 
 from bzrlib import (

=== modified file 'bzrlib/benchmarks/bench_checkout.py'
--- bzrlib/benchmarks/bench_checkout.py	2006-08-15 03:19:49 +0000
+++ bzrlib/benchmarks/bench_checkout.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_commit.py'
--- bzrlib/benchmarks/bench_commit.py	2006-08-18 13:16:52 +0000
+++ bzrlib/benchmarks/bench_commit.py	2006-10-16 01:25:46 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_info.py'
--- bzrlib/benchmarks/bench_info.py	2006-08-30 19:44:06 +0000
+++ bzrlib/benchmarks/bench_info.py	2006-10-16 01:25:46 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_inventory.py'
--- bzrlib/benchmarks/bench_inventory.py	2006-06-13 12:54:39 +0000
+++ bzrlib/benchmarks/bench_inventory.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_log.py'
--- bzrlib/benchmarks/bench_log.py	2006-08-07 22:00:11 +0000
+++ bzrlib/benchmarks/bench_log.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_osutils.py'
--- bzrlib/benchmarks/bench_osutils.py	2006-08-14 23:49:01 +0000
+++ bzrlib/benchmarks/bench_osutils.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_rocks.py'
--- bzrlib/benchmarks/bench_rocks.py	2006-10-09 23:44:19 +0000
+++ bzrlib/benchmarks/bench_rocks.py	2006-10-16 01:25:46 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_sftp.py'
--- bzrlib/benchmarks/bench_sftp.py	2006-09-22 03:29:29 +0000
+++ bzrlib/benchmarks/bench_sftp.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_startup.py'
--- bzrlib/benchmarks/bench_startup.py	2006-10-09 23:44:19 +0000
+++ bzrlib/benchmarks/bench_startup.py	2006-10-16 01:25:46 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_status.py'
--- bzrlib/benchmarks/bench_status.py	2006-08-18 16:42:15 +0000
+++ bzrlib/benchmarks/bench_status.py	2006-10-16 01:25:46 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_transform.py'
--- bzrlib/benchmarks/bench_transform.py	2006-08-14 23:49:01 +0000
+++ bzrlib/benchmarks/bench_transform.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_workingtree.py'
--- bzrlib/benchmarks/bench_workingtree.py	2006-08-15 03:19:49 +0000
+++ bzrlib/benchmarks/bench_workingtree.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/bench_xml.py'
--- bzrlib/benchmarks/bench_xml.py	2006-08-16 23:38:03 +0000
+++ bzrlib/benchmarks/bench_xml.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/benchmarks/tree_creator/__init__.py'
--- bzrlib/benchmarks/tree_creator/__init__.py	2006-08-15 03:04:06 +0000
+++ bzrlib/benchmarks/tree_creator/__init__.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/benchmarks/tree_creator/heavily_merged.py'
--- bzrlib/benchmarks/tree_creator/heavily_merged.py	2006-08-23 10:30:07 +0000
+++ bzrlib/benchmarks/tree_creator/heavily_merged.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/benchmarks/tree_creator/kernel_like.py'
--- bzrlib/benchmarks/tree_creator/kernel_like.py	2006-08-17 23:09:00 +0000
+++ bzrlib/benchmarks/tree_creator/kernel_like.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/benchmarks/tree_creator/many_commit.py'
--- bzrlib/benchmarks/tree_creator/many_commit.py	2006-08-30 19:44:06 +0000
+++ bzrlib/benchmarks/tree_creator/many_commit.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/benchmarks/tree_creator/simple_many_commit.py'
--- bzrlib/benchmarks/tree_creator/simple_many_commit.py	2006-08-15 03:04:06 +0000
+++ bzrlib/benchmarks/tree_creator/simple_many_commit.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-10-13 06:41:04 +0000
+++ bzrlib/builtins.py	2006-10-16 06:31:55 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005, 2006 by Canonical Ltd
+# Copyright (C) 2004, 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1291,6 +1291,8 @@
         for file_id in inv:
             if file_id in basis_inv:
                 continue
+            if inv.is_root(file_id) and len(basis_inv) == 0:
+                continue
             path = inv.id2path(file_id)
             if not os.access(osutils.abspath(path), os.F_OK):
                 continue
@@ -1503,7 +1505,7 @@
             tree = tree.branch.repository.revision_tree(
                 revision[0].in_history(tree.branch).rev_id)
 
-        for fp, fc, kind, fid, entry in tree.list_files():
+        for fp, fc, kind, fid, entry in tree.list_files(include_root=False):
             if fp.startswith(relpath):
                 fp = fp[len(relpath):]
                 if non_recursive and '/' in fp:
@@ -2326,11 +2328,11 @@
                     for name, ie in tree.inventory.iter_entries(file_id):
                         interesting_ids.add(ie.file_id)
                 new_conflicts = conflicts.select_conflicts(tree, file_list)[0]
+            else:
+                restore_files = [c.path for c in conflicts]
             _mod_merge.transform_tree(tree, tree.basis_tree(), interesting_ids)
             tree.set_conflicts(ConflictList(new_conflicts))
-            if file_list is None:
-                restore_files = list(tree.iter_conflicts())
-            else:
+            if file_list is not None:
                 restore_files = file_list
             for filename in restore_files:
                 try:

=== modified file 'bzrlib/bundle/__init__.py'
--- bzrlib/bundle/__init__.py	2006-10-06 05:53:44 +0000
+++ bzrlib/bundle/__init__.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/bundle/apply_bundle.py'
--- bzrlib/bundle/apply_bundle.py	2006-06-20 02:32:24 +0000
+++ bzrlib/bundle/apply_bundle.py	2006-10-05 05:37:25 +0000
@@ -1,3 +1,18 @@
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """\
 This contains functionality for installing bundles into repositories
 """

=== modified file 'bzrlib/bundle/bundle_data.py'
--- bzrlib/bundle/bundle_data.py	2006-09-26 13:28:39 +0000
+++ bzrlib/bundle/bundle_data.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -648,22 +648,16 @@
 
         assert self.base_tree is not None
         base_inv = self.base_tree.inventory
-        root_id = base_inv.root.file_id
-        try:
-            # New inventories have a unique root_id
-            inv = Inventory(root_id, self.revision_id)
-        except TypeError:
-            inv = Inventory(revision_id=self.revision_id)
-        inv.root.revision = self.get_last_changed(root_id)
+        inv = Inventory(None, self.revision_id)
 
         def add_entry(file_id):
             path = self.id2path(file_id)
             if path is None:
                 return
-            parent_path = dirname(path)
-            if parent_path == u'':
-                parent_id = root_id
+            if path == '':
+                parent_id = None
             else:
+                parent_path = dirname(path)
                 parent_id = self.path2id(parent_path)
 
             kind = self.get_kind(file_id)
@@ -690,8 +684,6 @@
 
         sorted_entries = self.sorted_path_id()
         for path, file_id in sorted_entries:
-            if file_id == inv.root.file_id:
-                continue
             add_entry(file_id)
 
         return inv

=== modified file 'bzrlib/bundle/commands.py'
--- bzrlib/bundle/commands.py	2006-09-12 22:12:30 +0000
+++ bzrlib/bundle/commands.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,18 @@
-#!/usr/bin/env python
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """\
 This is an attempt to take the internal delta object, and represent
 it as a single-file text-only changeset.

=== modified file 'bzrlib/bundle/common.py'
--- bzrlib/bundle/common.py	2006-07-10 15:15:40 +0000
+++ bzrlib/bundle/common.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,18 @@
-#!/usr/bin/env python
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """\
 Common entries, like strings, etc, for the bundle reading + writing code.
 """

=== modified file 'bzrlib/bundle/old/send_changeset.py'
--- bzrlib/bundle/old/send_changeset.py	2005-11-19 04:22:51 +0000
+++ bzrlib/bundle/old/send_changeset.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,19 @@
-#!/usr/bin/env python
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 """\
 Generate a changeset and send it by mail.
 """

=== modified file 'bzrlib/bundle/serializer/__init__.py'
--- bzrlib/bundle/serializer/__init__.py	2006-09-27 20:16:08 +0000
+++ bzrlib/bundle/serializer/__init__.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# (C) 2005-2006 Canonical Development Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/bundle/serializer/v08.py'
--- bzrlib/bundle/serializer/v08.py	2006-09-27 20:16:08 +0000
+++ bzrlib/bundle/serializer/v08.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/bundle/serializer/v09.py'
--- bzrlib/bundle/serializer/v09.py	2006-09-27 20:16:08 +0000
+++ bzrlib/bundle/serializer/v09.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2006-10-11 00:23:23 +0000
+++ bzrlib/bzrdir.py	2006-10-12 03:19:14 +0000
@@ -685,7 +685,12 @@
         # TODO: jam 20060426 we probably need a test in here in the
         #       case that the newly sprouted branch is a remote one
         if result_repo is None or result_repo.make_working_trees():
-            result.create_workingtree()
+            wt = result.create_workingtree()
+            if wt.inventory.root is None:
+                try:
+                    wt.set_root_id(self.open_workingtree.get_root_id())
+                except errors.NoWorkingTree:
+                    pass
         return result
 
 
@@ -1701,7 +1706,8 @@
                                                   entry_vf=w)
         for old_revision in previous_entries:
                 # if this fails, its a ghost ?
-                assert old_revision in self.converted_revs 
+                assert old_revision in self.converted_revs, \
+                    "Revision {%s} not in converted_revs" % old_revision
         self.snapshot_ie(previous_entries, ie, w, rev_id)
         del ie.text_id
         assert getattr(ie, 'revision', None) is not None

=== modified file 'bzrlib/cache_utf8.py'
--- bzrlib/cache_utf8.py	2006-08-16 22:05:26 +0000
+++ bzrlib/cache_utf8.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/check.py'
--- bzrlib/check.py	2006-08-04 04:41:02 +0000
+++ bzrlib/check.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2006-10-06 05:53:44 +0000
+++ bzrlib/commands.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2006-09-26 23:15:00 +0000
+++ bzrlib/commit.py	2006-10-15 15:55:32 +0000
@@ -86,7 +86,7 @@
 from bzrlib.testament import Testament
 from bzrlib.trace import mutter, note, warning
 from bzrlib.xml5 import serializer_v5
-from bzrlib.inventory import Inventory, ROOT_ID, InventoryEntry
+from bzrlib.inventory import Inventory, InventoryEntry
 from bzrlib import symbol_versioning
 from bzrlib.symbol_versioning import (deprecated_passed,
         deprecated_function,
@@ -126,6 +126,8 @@
     def snapshot_change(self, change, path):
         if change == 'unchanged':
             return
+        if change == 'added' and path == '':
+            return
         note("%s %s", change, path)
 
     def completed(self, revno, rev_id):
@@ -390,6 +392,10 @@
         # A merge with no effect on files
         if len(self.parents) > 1:
             return
+        # work around the fact that a newly-initted tree does differ from its
+        # basis
+        if len(self.basis_inv) == 0 and len(self.builder.new_inventory) == 1:
+            raise PointlessCommit()
         # Shortcut, if the number of entries changes, then we obviously have
         # a change
         if len(self.builder.new_inventory) != len(self.basis_inv):
@@ -550,6 +556,7 @@
         # in bugs like #46635.  Any reason not to use/enhance Tree.changes_from?
         # ADHB 11-07-2006
         mutter("Selecting files for commit with filter %s", self.specific_files)
+        assert self.work_inv.root is not None
         entries = self.work_inv.iter_entries()
         if not self.builder.record_root_entry:
             symbol_versioning.warn('CommitBuilders should support recording'
@@ -574,7 +581,6 @@
                 else:
                     # this entry is new and not being committed
                     continue
-
             self.builder.record_entry_contents(ie, self.parent_invs, 
                 path, self.work_tree)
             # describe the nature of the change that has occurred relative to

=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2006-10-12 01:07:42 +0000
+++ bzrlib/config.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/conflicts.py'
--- bzrlib/conflicts.py	2006-10-06 07:36:16 +0000
+++ bzrlib/conflicts.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Aaron Bentley
+# Copyright (C) 2005 Aaron Bentley, Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/delta.py'
--- bzrlib/delta.py	2006-09-29 20:27:19 +0000
+++ bzrlib/delta.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -152,14 +152,14 @@
         want_unchanged=want_unchanged,
         specific_files=specific_files,
         extra_trees=extra_trees,
-        require_versioned=require_versioned)
+        require_versioned=require_versioned,
+        include_root=False)
 
 
 def _compare_trees(old_tree, new_tree, want_unchanged, specific_file_ids,
                    include_root):
 
     from osutils import is_inside_any
-    
     old_inv = old_tree.inventory
     new_inv = new_tree.inventory
     delta = TreeDelta()

=== modified file 'bzrlib/doc/__init__.py'
--- bzrlib/doc/__init__.py	2006-07-28 16:05:23 +0000
+++ bzrlib/doc/__init__.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# (C) 2005 Canonical Development Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/doc/api/__init__.py'
--- bzrlib/doc/api/__init__.py	2006-07-30 07:02:22 +0000
+++ bzrlib/doc/api/__init__.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical Development Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2006-10-13 10:50:33 +0000
+++ bzrlib/errors.py	2006-10-17 14:01:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -183,6 +183,14 @@
         self.branch = branch
 
 
+class InventoryModified(BzrNewError):
+    """The current inventory for the tree %(tree)r has been modified, so a clean inventory cannot be read without data loss."""
+
+    def __init__(self, tree):
+        BzrNewError.__init__(self)
+        self.tree = tree
+
+
 class NoSuchId(BzrNewError):
     """The file id %(file_id)s is not present in the tree %(tree)s."""
     
@@ -212,6 +220,14 @@
         self.url = url
 
 
+class NotWriteLocked(BzrNewError):
+    """%(not_locked)r is not write locked but needs to be."""
+
+    def __init__(self, not_locked):
+        BzrNewError.__init__(self)
+        self.not_locked = not_locked
+
+
 class BzrCommandError(BzrNewError):
     """Error from user command"""
 
@@ -1020,6 +1036,18 @@
     """Tree transform is malformed %(conflicts)r"""
 
 
+class NoFinalPath(BzrNewError):
+    """No final name for trans_id %(trans_id)r
+    file-id: %(file_id)r"
+    root trans-id: %(root_trans_id)r 
+    """
+
+    def __init__(self, trans_id, transform):
+        self.trans_id = trans_id
+        self.file_id = transform.final_file_id(trans_id)
+        self.root_trans_id = transform.root
+
+
 class BzrBadParameter(BzrNewError):
     """A bad parameter : %(param)s is not usable.
     

=== modified file 'bzrlib/externalcommand.py'
--- bzrlib/externalcommand.py	2006-07-28 16:05:23 +0000
+++ bzrlib/externalcommand.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005 by Canonical Ltd
+# Copyright (C) 2004, 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/fetch.py'
--- bzrlib/fetch.py	2006-09-10 02:18:31 +0000
+++ bzrlib/fetch.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/gpg.py'
--- bzrlib/gpg.py	2006-09-12 20:02:29 +0000
+++ bzrlib/gpg.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/graph.py'
--- bzrlib/graph.py	2006-07-28 16:05:23 +0000
+++ bzrlib/graph.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# (C) 2005 Canonical
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/hashcache.py'
--- bzrlib/hashcache.py	2006-08-16 18:38:57 +0000
+++ bzrlib/hashcache.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/help.py'
--- bzrlib/help.py	2006-09-25 21:54:28 +0000
+++ bzrlib/help.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005, 2006 by Canonical Ltd
+# Copyright (C) 2004, 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/identitymap.py'
--- bzrlib/identitymap.py	2006-03-06 06:06:07 +0000
+++ bzrlib/identitymap.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/ignores.py'
--- bzrlib/ignores.py	2006-07-31 14:04:26 +0000
+++ bzrlib/ignores.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical Development Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/info.py'
--- bzrlib/info.py	2006-09-08 18:52:17 +0000
+++ bzrlib/info.py	2006-10-16 01:50:48 +0000
@@ -1,15 +1,15 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -210,9 +210,10 @@
     print '  %8d ignored' % ignore_cnt
 
     dir_cnt = 0
-    entries = work_inv.iter_entries()
-    entries.next()
-    dir_cnt = sum(1 for path, ie in entries if ie.kind == 'directory')
+    for file_id in work_inv:
+        if (work_inv.get_file_kind(file_id) == 'directory' and 
+            not work_inv.is_root(file_id)):
+            dir_cnt += 1
     print '  %8d versioned %s' \
           % (dir_cnt,
              plural(dir_cnt, 'subdirectory', 'subdirectories'))

=== modified file 'bzrlib/inspect_for_copy.py'
--- bzrlib/inspect_for_copy.py	2006-10-06 05:53:44 +0000
+++ bzrlib/inspect_for_copy.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical Development Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/inventory.py'
--- bzrlib/inventory.py	2006-10-06 05:53:44 +0000
+++ bzrlib/inventory.py	2006-10-12 01:50:46 +0000
@@ -855,6 +855,9 @@
     ['', u'hello.c']
     >>> inv = Inventory('TREE_ROOT-12345678-12345678')
     >>> inv.add(InventoryFile('123-123', 'hello.c', ROOT_ID))
+    Traceback (most recent call last):
+    BzrError: parent_id {TREE_ROOT} not in inventory
+    >>> inv.add(InventoryFile('123-123', 'hello.c', 'TREE_ROOT-12345678-12345678'))
     InventoryFile('123-123', 'hello.c', parent_id='TREE_ROOT-12345678-12345678', sha1=None, len=None)
     """
     def __init__(self, root_id=ROOT_ID, revision_id=None):
@@ -867,17 +870,11 @@
         The inventory is created with a default root directory, with
         an id of None.
         """
-        # We are letting Branch.create() create a unique inventory
-        # root id. Rather than generating a random one here.
-        #if root_id is None:
-        #    root_id = bzrlib.branch.gen_file_id('TREE_ROOT')
         if root_id is not None:
             self._set_root(InventoryDirectory(root_id, '', None))
         else:
             self.root = None
             self._byid = {}
-        # FIXME: this isn't ever used, changing it to self.revision may break
-        # things. TODO make everything use self.revision_id
         self.revision_id = revision_id
 
     def _set_root(self, ie):
@@ -904,7 +901,8 @@
     def iter_entries(self, from_dir=None):
         """Return (path, entry) pairs, in order by name."""
         if from_dir is None:
-            assert self.root
+            if self.root is None:
+                return
             from_dir = self.root
             yield '', self.root
         elif isinstance(from_dir, basestring):
@@ -957,7 +955,8 @@
         # TODO? Perhaps this should return the from_dir so that the root is
         # yielded? or maybe an option?
         if from_dir is None:
-            assert self.root
+            if self.root is None:
+                return
             from_dir = self.root
             yield '', self.root
         elif isinstance(from_dir, basestring):
@@ -1063,10 +1062,6 @@
             assert self.root is None and len(self._byid) == 0
             self._set_root(entry)
             return entry
-        if entry.parent_id == ROOT_ID:
-            assert self.root is not None, self
-            entry.parent_id = self.root.file_id
-
         try:
             parent = self._byid[entry.parent_id]
         except KeyError:
@@ -1205,6 +1200,8 @@
         # mutter("lookup path %r" % name)
 
         parent = self.root
+        if parent is None:
+            return None
         for f in name:
             try:
                 cie = parent.children[f]
@@ -1270,6 +1267,9 @@
         file_ie.name = new_name
         file_ie.parent_id = new_parent_id
 
+    def is_root(self, file_id):
+        return self.root is not None and file_id == self.root.file_id
+
 
 def make_entry(kind, name, parent_id, file_id=None):
     """Create an inventory entry.

=== modified file 'bzrlib/iterablefile.py'
--- bzrlib/iterablefile.py	2006-06-18 03:45:05 +0000
+++ bzrlib/iterablefile.py	2006-10-11 23:32:09 +0000
@@ -1,19 +1,20 @@
-# Copyright (C) 2005 Aaron Bentley
+# Copyright (C) 2005 Aaron Bentley, Canonical Ltd
 # <aaron.bentley@utoronto.ca>
 #
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 
 class IterableFileBase(object):
     """Create a file-like object from any iterable"""

=== modified file 'bzrlib/knit.py'
--- bzrlib/knit.py	2006-09-27 20:27:46 +0000
+++ bzrlib/knit.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 # Written by Martin Pool.
 # Modified by Johan Rydberg <jrydberg@gnu.org>
 # Modified by Robert Collins <robert.collins@canonical.com>

=== modified file 'bzrlib/lazy_import.py'
--- bzrlib/lazy_import.py	2006-10-06 05:53:44 +0000
+++ bzrlib/lazy_import.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/lazy_regex.py'
--- bzrlib/lazy_regex.py	2006-10-10 06:48:45 +0000
+++ bzrlib/lazy_regex.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2006-09-08 18:46:29 +0000
+++ bzrlib/log.py	2006-10-16 09:14:47 +0000
@@ -54,7 +54,9 @@
 from itertools import izip
 import re
 
+from bzrlib import symbol_versioning
 import bzrlib.errors as errors
+from bzrlib.symbol_versioning import deprecated_method, zero_eleven
 from bzrlib.trace import mutter
 from bzrlib.tsort import merge_sort
 
@@ -202,10 +204,20 @@
         mainline_revs.insert(0, None)
     else:
         mainline_revs.insert(0, which_revs[start_revision-2][1])
-    if getattr(lf, 'show_merge', None) is not None:
-        include_merges = True 
+    # how should we show merged revisions ?
+    # old api: show_merge. New api: show_merge_revno
+    show_merge_revno = getattr(lf, 'show_merge_revno', None)
+    show_merge = getattr(lf, 'show_merge', None)
+    if show_merge is None and show_merge_revno is None:
+        # no merged-revno support
+        include_merges = False
     else:
-        include_merges = False 
+        include_merges = True
+    if show_merge is not None and show_merge_revno is None:
+        # tell developers to update their code
+        symbol_versioning.warn('LogFormatters should provide show_merge_revno '
+            'instead of show_merge since bzr 0.11.',
+            DeprecationWarning, stacklevel=3)
     view_revisions = list(get_view_revisions(mainline_revs, rev_nos, branch,
                           direction, include_merges=include_merges))
 
@@ -253,7 +265,10 @@
 
             lf.show(revno, rev, delta)
         else:
-            lf.show_merge(rev, merge_depth)
+            if show_merge_revno is None:
+                lf.show_merge(rev, merge_depth)
+            else:
+                lf.show_merge_revno(rev, merge_depth, revno)
 
 
 def get_view_revisions(mainline_revs, rev_nos, branch, direction,
@@ -267,12 +282,13 @@
         if direction == 'reverse':
             revision_ids.reverse()
         for revision_id in revision_ids:
-            yield revision_id, rev_nos[revision_id], 0
+            yield revision_id, str(rev_nos[revision_id]), 0
         return
     merge_sorted_revisions = merge_sort(
         branch.repository.get_revision_graph(mainline_revs[-1]),
         mainline_revs[-1],
-        mainline_revs)
+        mainline_revs,
+        generate_revno=True)
 
     if direction == 'forward':
         # forward means oldest first.
@@ -282,8 +298,8 @@
 
     revision_history = branch.revision_history()
 
-    for sequence, rev_id, merge_depth, end_of_merge in merge_sorted_revisions:
-        yield rev_id, rev_nos.get(rev_id), merge_depth
+    for sequence, rev_id, merge_depth, revno, end_of_merge in merge_sorted_revisions:
+        yield rev_id, '.'.join(map(str, revno)), merge_depth
 
 
 def reverse_by_depth(merge_sorted_revisions, _depth=0):
@@ -329,16 +345,22 @@
     def show(self, revno, rev, delta):
         return self._show_helper(revno=revno, rev=rev, delta=delta)
 
+    @deprecated_method(zero_eleven)
     def show_merge(self, rev, merge_depth):
         return self._show_helper(rev=rev, indent='    '*merge_depth, merged=True, delta=None)
 
+    def show_merge_revno(self, rev, merge_depth, revno):
+        """Show a merged revision rev, with merge_depth and a revno."""
+        return self._show_helper(rev=rev, revno=revno,
+            indent='    '*merge_depth, merged=True, delta=None)
+
     def _show_helper(self, rev=None, revno=None, indent='', merged=False, delta=None):
         """Show a revision, either merged or not."""
         from bzrlib.osutils import format_date
         to_file = self.to_file
         print >>to_file,  indent+'-' * 60
         if revno is not None:
-            print >>to_file,  'revno:', revno
+            print >>to_file,  indent+'revno:', revno
         if merged:
             print >>to_file,  indent+'merged:', rev.revision_id
         elif self.show_ids:
@@ -375,7 +397,7 @@
         to_file = self.to_file
         date_str = format_date(rev.timestamp, rev.timezone or 0,
                             self.show_timezone)
-        print >>to_file, "%5d %s\t%s" % (revno, self.short_committer(rev),
+        print >>to_file, "%5s %s\t%s" % (revno, self.short_committer(rev),
                 format_date(rev.timestamp, rev.timezone or 0,
                             self.show_timezone, date_fmt="%Y-%m-%d",
                            show_offset=False))
@@ -428,7 +450,7 @@
         out = []
         if revno:
             # show revno only when is not None
-            out.append("%d:" % revno)
+            out.append("%s:" % revno)
         out.append(self.truncate(self.short_committer(rev), 20))
         out.append(self.date_string(rev))
         out.append(rev.get_summary())

=== modified file 'bzrlib/memorytree.py'
--- bzrlib/memorytree.py	2006-09-15 02:03:15 +0000
+++ bzrlib/memorytree.py	2006-09-22 04:52:17 +0000
@@ -167,8 +167,9 @@
         self._file_transport = MemoryTransport()
         # TODO copy the revision trees content, or do it lazy, or something.
         inventory_entries = self._inventory.iter_entries()
-        inventory_entries.next()
         for path, entry in inventory_entries:
+            if path == '':
+                continue
             if entry.kind == 'directory':
                 self._file_transport.mkdir(path)
             elif entry.kind == 'file':

=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2006-10-06 05:53:44 +0000
+++ bzrlib/merge.py	2006-10-12 01:50:46 +0000
@@ -45,7 +45,8 @@
 from bzrlib.textfile import check_text_lines
 from bzrlib.trace import mutter, warning, note
 from bzrlib.transform import (TreeTransform, resolve_conflicts, cook_conflicts,
-                              FinalPaths, create_by_entry, unique_add)
+                              FinalPaths, create_by_entry, unique_add,
+                              ROOT_PARENT)
 from bzrlib.versionedfile import WeaveMerge
 from bzrlib import ui
 
@@ -388,7 +389,7 @@
                     self.merge_executable(file_id, file_status)
             finally:
                 child_pb.finished()
-                
+            self.fix_root()
             self.pp.next_phase()
             child_pb = ui.ui_factory.nested_progress_bar()
             try:
@@ -410,6 +411,33 @@
             working_tree.unlock()
             self.pb.clear()
 
+    def fix_root(self):
+        try:
+            self.tt.final_kind(self.tt.root)
+        except NoSuchFile:
+            self.tt.cancel_deletion(self.tt.root)
+        if self.tt.final_file_id(self.tt.root) is None:
+            self.tt.version_file(self.tt.tree_file_id(self.tt.root), 
+                                 self.tt.root)
+        if self.other_tree.inventory.root is None:
+            return
+        other_root_file_id = self.other_tree.inventory.root.file_id
+        other_root = self.tt.trans_id_file_id(other_root_file_id)
+        if other_root == self.tt.root:
+            return
+        try:
+            self.tt.final_kind(other_root)
+        except NoSuchFile:
+            return
+        self.reparent_children(self.other_tree.inventory.root, self.tt.root)
+        self.tt.cancel_creation(other_root)
+        self.tt.cancel_versioning(other_root)
+
+    def reparent_children(self, ie, target):
+        for thing, child in ie.children.iteritems():
+            trans_id = self.tt.trans_id_file_id(child.file_id)
+            self.tt.adjust_path(self.tt.final_name(trans_id), target, trans_id)
+
     def write_modified(self, results):
         modified_hashes = {}
         for path in results.modified_paths:
@@ -520,9 +548,10 @@
                         "conflict": other_entry}
         trans_id = self.tt.trans_id_file_id(file_id)
         parent_id = winner_entry[parent_id_winner].parent_id
-        parent_trans_id = self.tt.trans_id_file_id(parent_id)
-        self.tt.adjust_path(winner_entry[name_winner].name, parent_trans_id,
-                            trans_id)
+        if parent_id is not None:
+            parent_trans_id = self.tt.trans_id_file_id(parent_id)
+            self.tt.adjust_path(winner_entry[name_winner].name, 
+                                parent_trans_id, trans_id)
 
     def merge_contents(self, file_id):
         """Performa a merge on file_id contents."""

=== modified file 'bzrlib/merge3.py'
--- bzrlib/merge3.py	2006-07-28 16:05:23 +0000
+++ bzrlib/merge3.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005 by Canonical Ltd
+# Copyright (C) 2004, 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/missing.py'
--- bzrlib/missing.py	2006-07-26 07:11:35 +0000
+++ bzrlib/missing.py	2006-10-05 05:37:25 +0000
@@ -1,3 +1,19 @@
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 """Display what revisions are missing in 'other' from 'this' and vice versa."""
 
 import bzrlib.ui as ui

=== modified file 'bzrlib/msgeditor.py'
--- bzrlib/msgeditor.py	2006-08-29 20:47:02 +0000
+++ bzrlib/msgeditor.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/mutabletree.py'
--- bzrlib/mutabletree.py	2006-09-15 02:03:15 +0000
+++ bzrlib/mutabletree.py	2006-09-22 04:52:17 +0000
@@ -100,8 +100,6 @@
             if self.is_control_filename(f):
                 raise errors.ForbiddenControlFileError(filename=f)
             fp = splitpath(f)
-            if len(fp) == 0:
-                raise BzrError("cannot add top-level %r" % f)
         # fill out file kinds for all files [not needed when we stop 
         # caring about the instantaneous file kind within a uncommmitted tree
         #

=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2006-10-06 07:13:51 +0000
+++ bzrlib/option.py	2006-10-16 10:03:21 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005, 2006 by Canonical Ltd
+# Copyright (C) 2004, 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -86,6 +86,7 @@
     """
     # TODO: Maybe move this into revisionspec.py
     revs = []
+    # split on the first .. that is not followed by a / ?
     sep = re.compile("\\.\\.(?!/)")
     for x in sep.split(revstr):
         revs.append(revisionspec.RevisionSpec.from_string(x or None))

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2006-10-11 00:23:23 +0000
+++ bzrlib/osutils.py	2006-10-16 01:25:46 +0000
@@ -1,6 +1,6 @@
 # Bazaar -- distributed version control
 #
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/patches.py'
--- bzrlib/patches.py	2006-06-15 03:10:51 +0000
+++ bzrlib/patches.py	2006-10-11 23:32:09 +0000
@@ -1,19 +1,19 @@
-# Copyright (C) 2004 - 2006 Aaron Bentley
+# Copyright (C) 2004 - 2006 Aaron Bentley, Canonical Ltd
 # <aaron.bentley@utoronto.ca>
 #
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
 class PatchSyntax(Exception):

=== modified file 'bzrlib/plugin.py'
--- bzrlib/plugin.py	2006-09-13 03:21:03 +0000
+++ bzrlib/plugin.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005 by Canonical Ltd
+# Copyright (C) 2004, 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/plugins/__init__.py'
--- bzrlib/plugins/__init__.py	2005-09-19 06:05:19 +0000
+++ bzrlib/plugins/__init__.py	2006-10-11 23:08:27 +0000
@@ -1,1 +1,17 @@
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 """Null placeholder plugin"""

=== modified file 'bzrlib/plugins/launchpad/__init__.py'
--- bzrlib/plugins/launchpad/__init__.py	2006-05-16 02:31:06 +0000
+++ bzrlib/plugins/launchpad/__init__.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/plugins/launchpad/lp_registration.py'
--- bzrlib/plugins/launchpad/lp_registration.py	2006-05-16 02:31:06 +0000
+++ bzrlib/plugins/launchpad/lp_registration.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -7,8 +7,8 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
-# # GNU General Public License for more details.
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software

=== modified file 'bzrlib/plugins/launchpad/test_register.py'
--- bzrlib/plugins/launchpad/test_register.py	2006-09-21 23:06:54 +0000
+++ bzrlib/plugins/launchpad/test_register.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/progress.py'
--- bzrlib/progress.py	2006-10-06 07:29:17 +0000
+++ bzrlib/progress.py	2006-10-16 01:25:46 +0000
@@ -1,19 +1,19 @@
 # Copyright (C) 2005 Aaron Bentley <aaron.bentley@utoronto.ca>
-# Copyright (C) 2005, 2006 Canonical <canonical.com>
-#
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
 """Simple text-mode progress indicator.

=== modified file 'bzrlib/reconcile.py'
--- bzrlib/reconcile.py	2006-06-20 03:57:11 +0000
+++ bzrlib/reconcile.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# (C) 2005, 2006 Canonical Limited.
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/registry.py'
--- bzrlib/registry.py	2006-10-13 00:55:26 +0000
+++ bzrlib/registry.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2006-10-06 05:53:44 +0000
+++ bzrlib/repository.py	2006-10-12 01:50:46 +0000
@@ -605,7 +605,8 @@
         # TODO: refactor this to use an existing revision object
         # so we don't need to read it in twice.
         if revision_id is None or revision_id == _mod_revision.NULL_REVISION:
-            return RevisionTree(self, Inventory(), _mod_revision.NULL_REVISION)
+            return RevisionTree(self, Inventory(root_id=None), 
+                                _mod_revision.NULL_REVISION)
         else:
             inv = self.get_revision_inventory(revision_id)
             return RevisionTree(self, inv, revision_id)

=== modified file 'bzrlib/revision.py'
--- bzrlib/revision.py	2006-08-30 13:54:51 +0000
+++ bzrlib/revision.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/revisionspec.py'
--- bzrlib/revisionspec.py	2006-09-03 15:58:15 +0000
+++ bzrlib/revisionspec.py	2006-10-16 09:15:41 +0000
@@ -24,6 +24,7 @@
     revision,
     symbol_versioning,
     trace,
+    tsort,
     )
 
 
@@ -152,9 +153,11 @@
         else:
             # RevisionSpec_revno is special cased, because it is the only
             # one that directly handles plain integers
+            # TODO: This should not be special cased rather it should be
+            # a method invocation on spectype.canparse()
             global _revno_regex
             if _revno_regex is None:
-                _revno_regex = re.compile(r'-?\d+(:.*)?$')
+                _revno_regex = re.compile(r'^(?:(\d+(\.\d+)*)|-\d+)(:.*)?$')
             if _revno_regex.match(spec) is not None:
                 return RevisionSpec_revno(spec, _internal=True)
 
@@ -199,6 +202,8 @@
         if branch:
             revs = branch.revision_history()
         else:
+            # this should never trigger.
+            # TODO: make it a deprecated code path. RBC 20060928
             revs = None
         return self._match_on_and_check(branch, revs)
 
@@ -255,26 +260,57 @@
         else:
             try:
                 revno = int(revno_spec)
-            except ValueError, e:
-                raise errors.InvalidRevisionSpec(self.user_spec,
-                                                 branch, e)
+                dotted = False
+            except ValueError:
+                # dotted decimal. This arguably should not be here
+                # but the from_string method is a little primitive 
+                # right now - RBC 20060928
+                try:
+                    match_revno = tuple((int(number) for number in revno_spec.split('.')))
+                except ValueError, e:
+                    raise errors.InvalidRevisionSpec(self.user_spec, branch, e)
+
+                dotted = True
 
         if branch_spec:
+            # the user has override the branch to look in.
+            # we need to refresh the revision_history map and
+            # the branch object.
             from bzrlib.branch import Branch
             branch = Branch.open(branch_spec)
             # Need to use a new revision history
             # because we are using a specific branch
             revs = branch.revision_history()
 
-        if revno < 0:
-            if (-revno) >= len(revs):
-                revno = 1
+        if dotted:
+            branch.lock_read()
+            try:
+                last_rev = branch.last_revision()
+                merge_sorted_revisions = tsort.merge_sort(
+                    branch.repository.get_revision_graph(last_rev),
+                    last_rev,
+                    generate_revno=True)
+                def match(item):
+                    return item[3] == match_revno
+                revisions = filter(match, merge_sorted_revisions)
+            finally:
+                branch.unlock()
+            if len(revisions) != 1:
+                return RevisionInfo(branch, None, None)
             else:
-                revno = len(revs) + revno + 1
-        try:
-            revision_id = branch.get_rev_id(revno, revs)
-        except errors.NoSuchRevision:
-            raise errors.InvalidRevisionSpec(self.user_spec, branch)
+                # there is no traditional 'revno' for dotted-decimal revnos.
+                # so for  API compatability we return None.
+                return RevisionInfo(branch, None, revisions[0][1])
+        else:
+            if revno < 0:
+                if (-revno) >= len(revs):
+                    revno = 1
+                else:
+                    revno = len(revs) + revno + 1
+            try:
+                revision_id = branch.get_rev_id(revno, revs)
+            except errors.NoSuchRevision:
+                raise errors.InvalidRevisionSpec(self.user_spec, branch)
         return RevisionInfo(branch, revno, revision_id)
         
     def needs_branch(self):

=== modified file 'bzrlib/revisiontree.py'
--- bzrlib/revisiontree.py	2006-09-21 23:23:03 +0000
+++ bzrlib/revisiontree.py	2006-09-28 01:53:23 +0000
@@ -40,7 +40,6 @@
         self._repository = branch
         self._weave_store = branch.weave_store
         self._inventory = inv
-        assert inv.root is not None
         self._revision_id = revision_id
 
     def get_parent_ids(self):
@@ -100,7 +99,8 @@
     def list_files(self, include_root=False):
         # The only files returned by this are those from the version
         entries = self.inventory.iter_entries()
-        if not include_root:
+        # skip the root for compatability with the current apis.
+        if self.inventory.root is not None and not include_root:
             # skip the root for compatability with the current apis.
             entries.next()
         for path, entry in entries:

=== modified file 'bzrlib/rio.py'
--- bzrlib/rio.py	2006-09-22 19:37:57 +0000
+++ bzrlib/rio.py	2006-10-11 23:08:27 +0000
@@ -1,6 +1,18 @@
-# Copyright (C) 2005 by Canonical Ltd
-#
-# Distributed under the GNU General Public Licence v2
+# Copyright (C) 2005 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 # \subsection{\emph{rio} - simple text metaformat}
 # 

=== modified file 'bzrlib/shellcomplete.py'
--- bzrlib/shellcomplete.py	2006-09-08 18:46:29 +0000
+++ bzrlib/shellcomplete.py	2006-10-05 05:37:25 +0000
@@ -1,3 +1,19 @@
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 import sys
 
 

=== modified file 'bzrlib/store/__init__.py'
--- bzrlib/store/__init__.py	2006-09-08 18:52:17 +0000
+++ bzrlib/store/__init__.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Development Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/store/revision/__init__.py'
--- bzrlib/store/revision/__init__.py	2006-09-12 21:19:54 +0000
+++ bzrlib/store/revision/__init__.py	2006-10-16 01:25:46 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/store/revision/knit.py'
--- bzrlib/store/revision/knit.py	2006-06-20 05:32:16 +0000
+++ bzrlib/store/revision/knit.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/store/revision/text.py'
--- bzrlib/store/revision/text.py	2006-06-12 02:07:37 +0000
+++ bzrlib/store/revision/text.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/store/text.py'
--- bzrlib/store/text.py	2006-09-08 18:52:17 +0000
+++ bzrlib/store/text.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Development Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/symbol_versioning.py'
--- bzrlib/symbol_versioning.py	2006-09-25 01:10:49 +0000
+++ bzrlib/symbol_versioning.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/testament.py'
--- bzrlib/testament.py	2006-09-26 13:28:39 +0000
+++ bzrlib/testament.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/EncodingAdapter.py'
--- bzrlib/tests/EncodingAdapter.py	2006-06-11 03:09:28 +0000
+++ bzrlib/tests/EncodingAdapter.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/HTTPTestUtil.py'
--- bzrlib/tests/HTTPTestUtil.py	2006-10-13 15:53:16 +0000
+++ bzrlib/tests/HTTPTestUtil.py	2006-10-17 14:01:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/TestUtil.py'
--- bzrlib/tests/TestUtil.py	2006-05-16 06:45:43 +0000
+++ bzrlib/tests/TestUtil.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (c) 2004 Canonical Limited
+# Copyright (C) 2004, 2005, 2006 Canonical Ltd
 #       Author: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-10-13 15:53:16 +0000
+++ bzrlib/tests/__init__.py	2006-10-17 14:01:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/__init__.py'
--- bzrlib/tests/blackbox/__init__.py	2006-09-23 06:39:46 +0000
+++ bzrlib/tests/blackbox/__init__.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_add.py'
--- bzrlib/tests/blackbox/test_add.py	2006-09-07 21:31:58 +0000
+++ bzrlib/tests/blackbox/test_add.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_added.py'
--- bzrlib/tests/blackbox/test_added.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/blackbox/test_added.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_aliases.py'
--- bzrlib/tests/blackbox/test_aliases.py	2006-06-15 05:36:34 +0000
+++ bzrlib/tests/blackbox/test_aliases.py	2006-10-05 05:37:25 +0000
@@ -1,3 +1,18 @@
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """Black-box tests for bzr aliases.
 """
 

=== modified file 'bzrlib/tests/blackbox/test_ancestry.py'
--- bzrlib/tests/blackbox/test_ancestry.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/blackbox/test_ancestry.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_annotate.py'
--- bzrlib/tests/blackbox/test_annotate.py	2006-09-21 19:41:29 +0000
+++ bzrlib/tests/blackbox/test_annotate.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_bound_branches.py'
--- bzrlib/tests/blackbox/test_bound_branches.py	2006-09-11 01:03:59 +0000
+++ bzrlib/tests/blackbox/test_bound_branches.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_branch.py'
--- bzrlib/tests/blackbox/test_branch.py	2006-09-05 08:14:23 +0000
+++ bzrlib/tests/blackbox/test_branch.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_bundle.py'
--- bzrlib/tests/blackbox/test_bundle.py	2006-06-26 18:01:07 +0000
+++ bzrlib/tests/blackbox/test_bundle.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors: Aaron Bentley
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_cat.py'
--- bzrlib/tests/blackbox/test_cat.py	2006-09-11 06:07:02 +0000
+++ bzrlib/tests/blackbox/test_cat.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_checkout.py'
--- bzrlib/tests/blackbox/test_checkout.py	2006-09-05 08:14:23 +0000
+++ bzrlib/tests/blackbox/test_checkout.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_command_encoding.py'
--- bzrlib/tests/blackbox/test_command_encoding.py	2006-06-07 16:05:27 +0000
+++ bzrlib/tests/blackbox/test_command_encoding.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_commit.py'
--- bzrlib/tests/blackbox/test_commit.py	2006-09-04 08:00:00 +0000
+++ bzrlib/tests/blackbox/test_commit.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_conflicts.py'
--- bzrlib/tests/blackbox/test_conflicts.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/blackbox/test_conflicts.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_diff.py'
--- bzrlib/tests/blackbox/test_diff.py	2006-07-31 19:15:36 +0000
+++ bzrlib/tests/blackbox/test_diff.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_exceptions.py'
--- bzrlib/tests/blackbox/test_exceptions.py	2006-08-17 11:10:57 +0000
+++ bzrlib/tests/blackbox/test_exceptions.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_export.py'
--- bzrlib/tests/blackbox/test_export.py	2006-09-23 19:05:44 +0000
+++ bzrlib/tests/blackbox/test_export.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_find_merge_base.py'
--- bzrlib/tests/blackbox/test_find_merge_base.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/blackbox/test_find_merge_base.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_help.py'
--- bzrlib/tests/blackbox/test_help.py	2006-07-30 07:02:22 +0000
+++ bzrlib/tests/blackbox/test_help.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_ignore.py'
--- bzrlib/tests/blackbox/test_ignore.py	2006-10-05 22:42:09 +0000
+++ bzrlib/tests/blackbox/test_ignore.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_ignored.py'
--- bzrlib/tests/blackbox/test_ignored.py	2006-05-18 23:48:54 +0000
+++ bzrlib/tests/blackbox/test_ignored.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_info.py'
--- bzrlib/tests/blackbox/test_info.py	2006-09-11 01:03:59 +0000
+++ bzrlib/tests/blackbox/test_info.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_init.py'
--- bzrlib/tests/blackbox/test_init.py	2006-09-05 11:22:35 +0000
+++ bzrlib/tests/blackbox/test_init.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_inventory.py'
--- bzrlib/tests/blackbox/test_inventory.py	2006-09-22 21:39:54 +0000
+++ bzrlib/tests/blackbox/test_inventory.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_locale.py'
--- bzrlib/tests/blackbox/test_locale.py	2006-09-12 21:25:01 +0000
+++ bzrlib/tests/blackbox/test_locale.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_log.py'
--- bzrlib/tests/blackbox/test_log.py	2006-08-06 17:31:40 +0000
+++ bzrlib/tests/blackbox/test_log.py	2006-10-16 10:03:21 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify
@@ -136,6 +136,7 @@
 #message:
 #  merge branch 1
 #    ------------------------------------------------------------
+#    revno: 1.1.2  
 #    merged: foo@example.com-20060328113140-91f43cfb46dc2863
 #    committer: Robert Collins <foo@example.com>
 #    branch nick: child
@@ -143,6 +144,7 @@
 #    message:
 #      merge branch 2
 #        ------------------------------------------------------------
+#        revno: 1.1.1.1
 #        merged: foo@example.com-20060328113140-1ba24f850a0ef573
 #        committer: Robert Collins <foo@example.com>
 #        branch nick: smallerchild
@@ -150,6 +152,7 @@
 #        message:
 #          branch 2
 #    ------------------------------------------------------------
+#    revno: 1.1.1
 #    merged: foo@example.com-20060328113140-5749a4757a8ac792
 #    committer: Robert Collins <foo@example.com>
 #    branch nick: child
@@ -165,11 +168,17 @@
 #  first post
 #""", out)
         # but we dont have a nice pattern matcher hooked up yet, so:
-        # we check for the indenting of the commit message:
+        # we check for the indenting of the commit message and the 
+        # revision numbers 
+        self.assertTrue('revno: 2' in out)
         self.assertTrue('  merge branch 1' in out)
+        self.assertTrue('    revno: 1.1.2' in out)
         self.assertTrue('      merge branch 2' in out)
+        self.assertTrue('        revno: 1.1.1.1' in out)
         self.assertTrue('          branch 2' in out)
+        self.assertTrue('    revno: 1.1.1' in out)
         self.assertTrue('      branch 1' in out)
+        self.assertTrue('revno: 1' in out)
         self.assertTrue('  first post' in out)
         self.assertEqual('', err)
 

=== modified file 'bzrlib/tests/blackbox/test_logformats.py'
--- bzrlib/tests/blackbox/test_logformats.py	2006-08-16 04:57:05 +0000
+++ bzrlib/tests/blackbox/test_logformats.py	2006-10-05 05:37:25 +0000
@@ -1,3 +1,18 @@
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """Black-box tests for default log_formats/log_formatters
 """
 

=== modified file 'bzrlib/tests/blackbox/test_ls.py'
--- bzrlib/tests/blackbox/test_ls.py	2006-09-07 21:31:58 +0000
+++ bzrlib/tests/blackbox/test_ls.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_missing.py'
--- bzrlib/tests/blackbox/test_missing.py	2006-06-07 17:23:59 +0000
+++ bzrlib/tests/blackbox/test_missing.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 # vim: encoding=utf-8
 #

=== modified file 'bzrlib/tests/blackbox/test_mv.py'
--- bzrlib/tests/blackbox/test_mv.py	2006-07-11 01:14:17 +0000
+++ bzrlib/tests/blackbox/test_mv.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_non_ascii.py'
--- bzrlib/tests/blackbox/test_non_ascii.py	2006-09-07 21:37:43 +0000
+++ bzrlib/tests/blackbox/test_non_ascii.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_outside_wt.py'
--- bzrlib/tests/blackbox/test_outside_wt.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/blackbox/test_outside_wt.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_pull.py'
--- bzrlib/tests/blackbox/test_pull.py	2006-09-05 08:14:23 +0000
+++ bzrlib/tests/blackbox/test_pull.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_push.py'
--- bzrlib/tests/blackbox/test_push.py	2006-10-10 00:15:25 +0000
+++ bzrlib/tests/blackbox/test_push.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_re_sign.py'
--- bzrlib/tests/blackbox/test_re_sign.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/blackbox/test_re_sign.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_reconcile.py'
--- bzrlib/tests/blackbox/test_reconcile.py	2006-08-24 18:37:24 +0000
+++ bzrlib/tests/blackbox/test_reconcile.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_remerge.py'
--- bzrlib/tests/blackbox/test_remerge.py	2006-08-16 04:57:05 +0000
+++ bzrlib/tests/blackbox/test_remerge.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_remove.py'
--- bzrlib/tests/blackbox/test_remove.py	2006-05-30 02:05:08 +0000
+++ bzrlib/tests/blackbox/test_remove.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_revert.py'
--- bzrlib/tests/blackbox/test_revert.py	2006-07-01 18:36:57 +0000
+++ bzrlib/tests/blackbox/test_revert.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_revision_history.py'
--- bzrlib/tests/blackbox/test_revision_history.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/blackbox/test_revision_history.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, Michael Ellerman
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_revision_info.py'
--- bzrlib/tests/blackbox/test_revision_info.py	2006-08-24 00:07:15 +0000
+++ bzrlib/tests/blackbox/test_revision_info.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005 by Canonical Ltd
+# Copyright (C) 2004, 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_revno.py'
--- bzrlib/tests/blackbox/test_revno.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/blackbox/test_revno.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_selftest.py'
--- bzrlib/tests/blackbox/test_selftest.py	2006-10-13 07:41:06 +0000
+++ bzrlib/tests/blackbox/test_selftest.py	2006-10-16 01:50:48 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/tests/blackbox/test_serve.py'
--- bzrlib/tests/blackbox/test_serve.py	2006-09-21 09:15:20 +0000
+++ bzrlib/tests/blackbox/test_serve.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_shared_repository.py'
--- bzrlib/tests/blackbox/test_shared_repository.py	2006-08-16 04:57:05 +0000
+++ bzrlib/tests/blackbox/test_shared_repository.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_sign_my_commits.py'
--- bzrlib/tests/blackbox/test_sign_my_commits.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/blackbox/test_sign_my_commits.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_status.py'
--- bzrlib/tests/blackbox/test_status.py	2006-09-07 21:37:43 +0000
+++ bzrlib/tests/blackbox/test_status.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_testament.py'
--- bzrlib/tests/blackbox/test_testament.py	2006-08-16 16:27:58 +0000
+++ bzrlib/tests/blackbox/test_testament.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_too_much.py'
--- bzrlib/tests/blackbox/test_too_much.py	2006-10-06 05:53:44 +0000
+++ bzrlib/tests/blackbox/test_too_much.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_uncommit.py'
--- bzrlib/tests/blackbox/test_uncommit.py	2006-09-11 01:03:59 +0000
+++ bzrlib/tests/blackbox/test_uncommit.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_update.py'
--- bzrlib/tests/blackbox/test_update.py	2006-08-25 05:03:17 +0000
+++ bzrlib/tests/blackbox/test_update.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_upgrade.py'
--- bzrlib/tests/blackbox/test_upgrade.py	2006-08-16 04:57:05 +0000
+++ bzrlib/tests/blackbox/test_upgrade.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors: Robert Collins <robert.collins@canonical.com>
 # -*- coding: utf-8 -*-
 #

=== modified file 'bzrlib/tests/blackbox/test_versioning.py'
--- bzrlib/tests/blackbox/test_versioning.py	2006-07-29 08:23:47 +0000
+++ bzrlib/tests/blackbox/test_versioning.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/blackbox/test_whoami.py'
--- bzrlib/tests/blackbox/test_whoami.py	2006-07-14 09:05:49 +0000
+++ bzrlib/tests/blackbox/test_whoami.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/branch_implementations/__init__.py'
--- bzrlib/tests/branch_implementations/__init__.py	2006-08-10 02:23:35 +0000
+++ bzrlib/tests/branch_implementations/__init__.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors: Robert Collins <robert.collins@canonical.com>
 # -*- coding: utf-8 -*-
 #

=== modified file 'bzrlib/tests/branch_implementations/test_break_lock.py'
--- bzrlib/tests/branch_implementations/test_break_lock.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/branch_implementations/test_break_lock.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# (C) 2006 Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/branch_implementations/test_parent.py'
--- bzrlib/tests/branch_implementations/test_parent.py	2006-08-10 02:23:35 +0000
+++ bzrlib/tests/branch_implementations/test_parent.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005, 2006 by Canonical Ltd
+# Copyright (C) 2004, 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/branch_implementations/test_permissions.py'
--- bzrlib/tests/branch_implementations/test_permissions.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/branch_implementations/test_permissions.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/branch_implementations/test_pull.py'
--- bzrlib/tests/branch_implementations/test_pull.py	2006-09-04 08:00:00 +0000
+++ bzrlib/tests/branch_implementations/test_pull.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005 by Canonical Ltd
+# Copyright (C) 2004, 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/branch_implementations/test_update.py'
--- bzrlib/tests/branch_implementations/test_update.py	2006-03-05 02:20:07 +0000
+++ bzrlib/tests/branch_implementations/test_update.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/bzrdir_implementations/__init__.py'
--- bzrlib/tests/bzrdir_implementations/__init__.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/bzrdir_implementations/__init__.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors: Robert Collins <robert.collins@canonical.com>
 # -*- coding: utf-8 -*-
 #

=== modified file 'bzrlib/tests/bzrdir_implementations/test_bzrdir.py'
--- bzrlib/tests/bzrdir_implementations/test_bzrdir.py	2006-09-29 16:34:45 +0000
+++ bzrlib/tests/bzrdir_implementations/test_bzrdir.py	2006-10-02 13:05:18 +0000
@@ -17,6 +17,7 @@
 """Tests for bzrdir implementations - tests a bzrdir format."""
 
 from cStringIO import StringIO
+import errno
 import os
 from stat import S_ISDIR
 import sys
@@ -536,11 +537,28 @@
         repo = dir.create_repository()
         repo.fetch(tree.branch.repository)
         self.assertTrue(repo.has_revision('1'))
+        try:
+            self.assertIs(dir.open_branch().last_revision(), None)
+        except errors.NotBranchError:
+            pass
         target = self.sproutOrSkip(dir, self.get_url('target'))
         self.assertNotEqual(dir.transport.base, target.transport.base)
+        # testing inventory isn't reasonable for repositories
         self.assertDirectoriesEqual(dir.root_transport, target.root_transport,
                                     ['./.bzr/repository/inventory.knit',
+                                     './.bzr/inventory'
                                      ])
+        try:
+            # If we happen to have a tree, we'll guarantee everything
+            # except for the tree root is the same.
+            inventory_f = file(dir.transport.base+'inventory', 'rb')
+            self.assertContainsRe(inventory_f.read(), 
+                                  '<inventory file_id="TREE_ROOT[^"]*"'
+                                  ' format="5">\n</inventory>\n')
+            inventory_f.close()
+        except IOError, e:
+            if e.errno != errno.ENOENT:
+                raise
 
     def test_sprout_bzrdir_with_repository_to_shared(self):
         tree = self.make_branch_and_tree('commit_tree')

=== modified file 'bzrlib/tests/interrepository_implementations/__init__.py'
--- bzrlib/tests/interrepository_implementations/__init__.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/interrepository_implementations/__init__.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors: Robert Collins <robert.collins@canonical.com>
 # -*- coding: utf-8 -*-
 #

=== modified file 'bzrlib/tests/interrepository_implementations/test_interrepository.py'
--- bzrlib/tests/interrepository_implementations/test_interrepository.py	2006-09-09 18:52:57 +0000
+++ bzrlib/tests/interrepository_implementations/test_interrepository.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# (C) 2005, 2006 Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/intertree_implementations/__init__.py'
--- bzrlib/tests/intertree_implementations/__init__.py	2006-07-25 06:50:12 +0000
+++ bzrlib/tests/intertree_implementations/__init__.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/intertree_implementations/test_compare.py'
--- bzrlib/tests/intertree_implementations/test_compare.py	2006-07-26 01:14:31 +0000
+++ bzrlib/tests/intertree_implementations/test_compare.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/interversionedfile_implementations/__init__.py'
--- bzrlib/tests/interversionedfile_implementations/__init__.py	2006-03-02 01:26:22 +0000
+++ bzrlib/tests/interversionedfile_implementations/__init__.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/interversionedfile_implementations/test_join.py'
--- bzrlib/tests/interversionedfile_implementations/test_join.py	2006-05-02 04:07:43 +0000
+++ bzrlib/tests/interversionedfile_implementations/test_join.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/repository_implementations/__init__.py'
--- bzrlib/tests/repository_implementations/__init__.py	2006-08-14 15:07:33 +0000
+++ bzrlib/tests/repository_implementations/__init__.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors: Robert Collins <robert.collins@canonical.com>
 # -*- coding: utf-8 -*-
 #

=== modified file 'bzrlib/tests/repository_implementations/test_break_lock.py'
--- bzrlib/tests/repository_implementations/test_break_lock.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/repository_implementations/test_break_lock.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/repository_implementations/test_commit_builder.py'
--- bzrlib/tests/repository_implementations/test_commit_builder.py	2006-09-26 20:46:11 +0000
+++ bzrlib/tests/repository_implementations/test_commit_builder.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/repository_implementations/test_fileid_involved.py'
--- bzrlib/tests/repository_implementations/test_fileid_involved.py	2006-09-09 18:52:57 +0000
+++ bzrlib/tests/repository_implementations/test_fileid_involved.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -176,9 +176,10 @@
     def fileids_altered_by_revision_ids(self, revision_ids):
         """This is a wrapper to strip TREE_ROOT if it occurs"""
         repo = self.branch.repository
+        root_id = self.branch.basis_tree().inventory.root.file_id
         result = repo.fileids_altered_by_revision_ids(revision_ids)
-        if 'TREE_ROOT' in result:
-            del result['TREE_ROOT']
+        if root_id in result:
+            del result[root_id]
         return result
 
     def test_fileids_altered_by_revision_ids(self):

=== modified file 'bzrlib/tests/repository_implementations/test_reconcile.py'
--- bzrlib/tests/repository_implementations/test_reconcile.py	2006-08-23 13:15:45 +0000
+++ bzrlib/tests/repository_implementations/test_reconcile.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/repository_implementations/test_repository.py'
--- bzrlib/tests/repository_implementations/test_repository.py	2006-09-29 11:15:51 +0000
+++ bzrlib/tests/repository_implementations/test_repository.py	2006-10-02 13:05:18 +0000
@@ -30,7 +30,7 @@
                            UninitializableFormat,
                            NotBranchError,
                            )
-from bzrlib.inventory import Inventory
+from bzrlib.inventory import Inventory, InventoryDirectory
 from bzrlib.revision import NULL_REVISION
 from bzrlib.tests import TestCase, TestCaseWithTransport, TestSkipped
 from bzrlib.tests.bzrdir_implementations.test_bzrdir import TestCaseWithBzrDir
@@ -153,13 +153,18 @@
 
     def test_revision_tree(self):
         wt = self.make_branch_and_tree('.')
+        wt.set_root_id('fixed-root')
         wt.commit('lala!', rev_id='revision-1', allow_pointless=True)
         tree = wt.branch.repository.revision_tree('revision-1')
-        self.assertEqual(list(tree.list_files()), [])
+        self.assertEqual('revision-1', tree.inventory.root.revision) 
+        expected = InventoryDirectory('fixed-root', '', None)
+        expected.revision = 'revision-1'
+        self.assertEqual([('', 'V', 'directory', 'fixed-root', expected)],
+                         list(tree.list_files(include_root=True)))
         tree = wt.branch.repository.revision_tree(None)
-        self.assertEqual([], list(tree.list_files()))
+        self.assertEqual([], list(tree.list_files(include_root=True)))
         tree = wt.branch.repository.revision_tree(NULL_REVISION)
-        self.assertEqual([], list(tree.list_files()))
+        self.assertEqual([], list(tree.list_files(include_root=True)))
 
     def test_fetch(self):
         # smoke test fetch to ensure that the convenience function works.

=== modified file 'bzrlib/tests/revisionstore_implementations/__init__.py'
--- bzrlib/tests/revisionstore_implementations/__init__.py	2006-03-03 02:09:49 +0000
+++ bzrlib/tests/revisionstore_implementations/__init__.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/revisionstore_implementations/test_all.py'
--- bzrlib/tests/revisionstore_implementations/test_all.py	2006-08-16 14:10:56 +0000
+++ bzrlib/tests/revisionstore_implementations/test_all.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_ancestry.py'
--- bzrlib/tests/test_ancestry.py	2006-10-04 04:50:23 +0000
+++ bzrlib/tests/test_ancestry.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,8 +35,11 @@
         """Test ancestry file when just committing."""
         tree = self.make_branch_and_memory_tree('.')
         branch = tree.branch
+        tree.lock_write()
+        tree.add('')
         rev_id_one = tree.commit('one')
         rev_id_two = tree.commit('two', allow_pointless=True)
+        tree.unlock()
 
         self.assertAncestryEqual([None, rev_id_one, rev_id_two],
             rev_id_two, branch)
@@ -44,9 +47,12 @@
 
     def test_none_is_always_an_ancestor(self):
         tree = self.make_branch_and_memory_tree('.')
+        tree.lock_write()
+        tree.add('')
         # note this is tested before any commits are done.
         self.assertTrue(is_ancestor(None, None, tree.branch))
         rev_id = tree.commit('one')
+        tree.unlock()
         self.assertTrue(is_ancestor(None, None, tree.branch))
         self.assertTrue(is_ancestor(rev_id, None, tree.branch))
         self.assertFalse(is_ancestor(None, rev_id, tree.branch))

=== modified file 'bzrlib/tests/test_api.py'
--- bzrlib/tests/test_api.py	2005-11-23 15:44:24 +0000
+++ bzrlib/tests/test_api.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_bad_files.py'
--- bzrlib/tests/test_bad_files.py	2006-09-08 18:52:17 +0000
+++ bzrlib/tests/test_bad_files.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_bundle.py'
--- bzrlib/tests/test_bundle.py	2006-10-06 05:53:44 +0000
+++ bzrlib/tests/test_bundle.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004-2006 by Canonical Ltd
+# Copyright (C) 2004, 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_bzrdir.py'
--- bzrlib/tests/test_bzrdir.py	2006-10-12 14:29:32 +0000
+++ bzrlib/tests/test_bzrdir.py	2006-10-17 14:01:12 +0000
@@ -4,12 +4,12 @@
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

=== modified file 'bzrlib/tests/test_command.py'
--- bzrlib/tests/test_command.py	2006-09-01 03:55:07 +0000
+++ bzrlib/tests/test_command.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005 by Canonical Ltd
+# Copyright (C) 2004, 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_commit.py'
--- bzrlib/tests/test_commit.py	2006-09-27 22:12:53 +0000
+++ bzrlib/tests/test_commit.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_commit_merge.py'
--- bzrlib/tests/test_commit_merge.py	2006-09-04 08:00:00 +0000
+++ bzrlib/tests/test_commit_merge.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -63,7 +63,9 @@
         wtx = self.make_branch_and_tree('x')
         base_rev = wtx.commit('common parent')
         bx = wtx.branch
+        wtx.commit('establish root id')
         wty = wtx.bzrdir.sprout('y').open_workingtree()
+        self.assertEqual(wtx.get_root_id(), wty.get_root_id())
         by = wty.branch
 
         self.build_tree(['x/ecks', 'y/why'])

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2006-10-12 01:07:42 +0000
+++ bzrlib/tests/test_config.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/test_conflicts.py'
--- bzrlib/tests/test_conflicts.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/test_conflicts.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_diff.py'
--- bzrlib/tests/test_diff.py	2006-08-25 20:43:30 +0000
+++ bzrlib/tests/test_diff.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical Development Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -9,7 +9,7 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

=== modified file 'bzrlib/tests/test_doc_generate.py'
--- bzrlib/tests/test_doc_generate.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/test_doc_generate.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_errors.py'
--- bzrlib/tests/test_errors.py	2006-09-28 04:01:35 +0000
+++ bzrlib/tests/test_errors.py	2006-10-16 04:50:19 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,13 @@
 
 class TestErrors(TestCaseWithTransport):
 
+    def test_inventory_modified(self):
+        error = errors.InventoryModified("a tree to be repred")
+        self.assertEqualDiff("The current inventory for the tree 'a tree to "
+            "be repred' has been modified, so a clean inventory cannot be "
+            "read without data loss.",
+            str(error))
+
     def test_medium_not_connected(self):
         error = errors.MediumNotConnected("a medium")
         self.assertEqualDiff(
@@ -49,6 +56,12 @@
             "atree.",
             str(error))
 
+    def test_not_write_locked(self):
+        error = errors.NotWriteLocked('a thing to repr')
+        self.assertEqualDiff("'a thing to repr' is not write locked but needs "
+            "to be.",
+            str(error))
+
     def test_too_many_concurrent_requests(self):
         error = errors.TooManyConcurrentRequests("a medium")
         self.assertEqualDiff("The medium 'a medium' has reached its concurrent "

=== modified file 'bzrlib/tests/test_escaped_store.py'
--- bzrlib/tests/test_escaped_store.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/test_escaped_store.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Development Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_fetch.py'
--- bzrlib/tests/test_fetch.py	2006-10-06 17:07:58 +0000
+++ bzrlib/tests/test_fetch.py	2006-10-17 14:01:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_ftp_transport.py'
--- bzrlib/tests/test_ftp_transport.py	2006-08-23 22:18:16 +0000
+++ bzrlib/tests/test_ftp_transport.py	2006-10-05 05:37:25 +0000
@@ -1,3 +1,5 @@
+# Copyright (C) 2006 Canonical Ltd
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or

=== modified file 'bzrlib/tests/test_gpg.py'
--- bzrlib/tests/test_gpg.py	2006-08-25 19:15:36 +0000
+++ bzrlib/tests/test_gpg.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/test_graph.py'
--- bzrlib/tests/test_graph.py	2006-03-22 16:26:09 +0000
+++ bzrlib/tests/test_graph.py	2006-10-11 23:08:27 +0000
@@ -1,6 +1,23 @@
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 from bzrlib.tests import TestCase
 from bzrlib.graph import node_distances, nodes_by_distance, Graph
 
+
 class TestBase(TestCase):
 
     def edge_add(self, *args):

=== modified file 'bzrlib/tests/test_http.py'
--- bzrlib/tests/test_http.py	2006-10-17 13:58:01 +0000
+++ bzrlib/tests/test_http.py	2006-10-17 14:01:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_http_response.py'
--- bzrlib/tests/test_http_response.py	2006-10-11 08:51:52 +0000
+++ bzrlib/tests/test_http_response.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_identitymap.py'
--- bzrlib/tests/test_identitymap.py	2005-11-23 15:44:24 +0000
+++ bzrlib/tests/test_identitymap.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/test_ignores.py'
--- bzrlib/tests/test_ignores.py	2006-07-21 04:02:14 +0000
+++ bzrlib/tests/test_ignores.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_inv.py'
--- bzrlib/tests/test_inv.py	2006-08-23 10:30:07 +0000
+++ bzrlib/tests/test_inv.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -544,3 +544,19 @@
         os.unlink('b1/a')
         wt.revert([])
         self.assertEqual(len(wt.inventory), 1)
+
+
+class TestIsRoot(TestCase):
+    """Ensure our root-checking code is accurate."""
+
+    def test_is_root(self):
+        inv = Inventory('TREE_ROOT')
+        self.assertTrue(inv.is_root('TREE_ROOT'))
+        self.assertFalse(inv.is_root('booga'))
+        inv.root.file_id = 'booga'
+        self.assertFalse(inv.is_root('TREE_ROOT'))
+        self.assertTrue(inv.is_root('booga'))
+        # works properly even if no root is set
+        inv.root = None
+        self.assertFalse(inv.is_root('TREE_ROOT'))
+        self.assertFalse(inv.is_root('booga'))

=== modified file 'bzrlib/tests/test_knit.py'
--- bzrlib/tests/test_knit.py	2006-09-26 13:40:43 +0000
+++ bzrlib/tests/test_knit.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_lazy_import.py'
--- bzrlib/tests/test_lazy_import.py	2006-09-13 02:16:02 +0000
+++ bzrlib/tests/test_lazy_import.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_lazy_regex.py'
--- bzrlib/tests/test_lazy_regex.py	2006-10-09 09:41:01 +0000
+++ bzrlib/tests/test_lazy_regex.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_lockable_files.py'
--- bzrlib/tests/test_lockable_files.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/test_lockable_files.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_log.py'
--- bzrlib/tests/test_log.py	2006-09-04 08:00:00 +0000
+++ bzrlib/tests/test_log.py	2006-10-16 10:03:21 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 # vim: encoding=utf-8
 #
@@ -126,7 +126,7 @@
         lf = LogCatcher()
         show_log(b, lf, verbose=True)
         eq(len(lf.logs), 1)
-        eq(lf.logs[0].revno, 1)
+        eq(lf.logs[0].revno, '1')
         eq(lf.logs[0].rev.message, 'empty commit')
         d = lf.logs[0].delta
         self.log('log delta: %r' % d)
@@ -149,11 +149,11 @@
         eq(len(lf.logs), 2)
         self.log('log entries:')
         for logentry in lf.logs:
-            self.log('%4d %s' % (logentry.revno, logentry.rev.message))
+            self.log('%4s %s' % (logentry.revno, logentry.rev.message))
         
         # first one is most recent
         logentry = lf.logs[0]
-        eq(logentry.revno, 2)
+        eq(logentry.revno, '2')
         eq(logentry.rev.message, 'add one file')
         d = logentry.delta
         self.log('log 2 delta: %r' % d)
@@ -325,6 +325,7 @@
         wt.commit('four-b', rev_id='4b')
         mainline_revs.append('4b')
         rev_nos['4b'] = 4
+        # 4a: 3.1.1
         return mainline_revs, rev_nos, wt
 
     def make_tree_with_many_merges(self):
@@ -332,9 +333,9 @@
         wt = self.make_branch_and_tree('tree1')
         wt.commit('commit one', rev_id='1')
         wt.commit('commit two', rev_id='2')
-        tree2 = wt.bzrdir.sprout('tree2').open_workingtree()
         tree3 = wt.bzrdir.sprout('tree3').open_workingtree()
         tree3.commit('commit three a', rev_id='3a')
+        tree2 = wt.bzrdir.sprout('tree2').open_workingtree()
         tree2.merge_from_branch(tree3.branch)
         tree2.commit('commit three b', rev_id='3b')
         wt.merge_from_branch(tree2.branch)
@@ -343,7 +344,16 @@
         wt.merge_from_branch(tree2.branch)
         wt.commit('four-b', rev_id='4b')
         mainline_revs = [None, '1', '2', '3c', '4b']
-        rev_nos = {'1': 1, '2': 2, '3c': 3, '4b': 4}
+        rev_nos = {'1':1, '2':2, '3c': 3, '4b':4}
+        full_rev_nos_for_reference = {
+            '1': '1',
+            '2': '2',
+            '3a': '2.2.1', #first commit tree 3
+            '3b': '2.1.1', # first commit tree 2
+            '3c': '3', #merges 3b to main
+            '4a': '2.1.2', # second commit tree 2
+            '4b': '4', # merges 4a to main
+            }
         return mainline_revs, rev_nos, wt
 
     def test_get_view_revisions_forward(self):
@@ -351,7 +361,8 @@
         mainline_revs, rev_nos, wt = self.make_tree_with_commits()
         revisions = list(get_view_revisions(mainline_revs, rev_nos, wt.branch,
                                             'forward'))
-        self.assertEqual(revisions, [('1', 1, 0), ('2', 2, 0), ('3', 3, 0)])
+        self.assertEqual([('1', '1', 0), ('2', '2', 0), ('3', '3', 0)],
+            revisions)
         revisions2 = list(get_view_revisions(mainline_revs, rev_nos, wt.branch,
                                              'forward', include_merges=False))
         self.assertEqual(revisions, revisions2)
@@ -361,7 +372,8 @@
         mainline_revs, rev_nos, wt = self.make_tree_with_commits()
         revisions = list(get_view_revisions(mainline_revs, rev_nos, wt.branch,
                                             'reverse'))
-        self.assertEqual(revisions, [('3', 3, 0), ('2', 2, 0), ('1', 1, 0), ])
+        self.assertEqual([('3', '3', 0), ('2', '2', 0), ('1', '1', 0), ],
+            revisions)
         revisions2 = list(get_view_revisions(mainline_revs, rev_nos, wt.branch,
                                              'reverse', include_merges=False))
         self.assertEqual(revisions, revisions2)
@@ -371,34 +383,40 @@
         mainline_revs, rev_nos, wt = self.make_tree_with_merges()
         revisions = list(get_view_revisions(mainline_revs, rev_nos, wt.branch,
                                             'forward'))
-        self.assertEqual(revisions, [('1', 1, 0), ('2', 2, 0), ('3', 3, 0),
-                                     ('4b', 4, 0), ('4a', None, 1)])
+        self.assertEqual([('1', '1', 0), ('2', '2', 0), ('3', '3', 0),
+            ('4b', '4', 0), ('4a', '3.1.1', 1)],
+            revisions)
         revisions = list(get_view_revisions(mainline_revs, rev_nos, wt.branch,
                                              'forward', include_merges=False))
-        self.assertEqual(revisions, [('1', 1, 0), ('2', 2, 0), ('3', 3, 0),
-                                     ('4b', 4, 0)])
+        self.assertEqual([('1', '1', 0), ('2', '2', 0), ('3', '3', 0),
+            ('4b', '4', 0)],
+            revisions)
 
     def test_get_view_revisions_merge_reverse(self):
         """Test get_view_revisions in reverse when there are merges"""
         mainline_revs, rev_nos, wt = self.make_tree_with_merges()
         revisions = list(get_view_revisions(mainline_revs, rev_nos, wt.branch,
                                             'reverse'))
-        self.assertEqual(revisions, [('4b', 4, 0), ('4a', None, 1), 
-                                     ('3', 3, 0), ('2', 2, 0), ('1', 1, 0)])
+        self.assertEqual([('4b', '4', 0), ('4a', '3.1.1', 1),
+            ('3', '3', 0), ('2', '2', 0), ('1', '1', 0)],
+            revisions)
         revisions = list(get_view_revisions(mainline_revs, rev_nos, wt.branch,
                                              'reverse', include_merges=False))
-        self.assertEqual(revisions, [('4b', 4, 0), ('3', 3, 0), ('2', 2, 0),
-                                     ('1', 1, 0)])
+        self.assertEqual([('4b', '4', 0), ('3', '3', 0), ('2', '2', 0),
+            ('1', '1', 0)],
+            revisions)
 
     def test_get_view_revisions_merge2(self):
         """Test get_view_revisions when there are merges"""
         mainline_revs, rev_nos, wt = self.make_tree_with_many_merges()
         revisions = list(get_view_revisions(mainline_revs, rev_nos, wt.branch,
                                             'forward'))
-        expected = [('1', 1, 0), ('2', 2, 0), ('3c', 3, 0), ('3a', None, 1),
-                    ('3b', None, 1), ('4b', 4, 0), ('4a', None, 1)]
-        self.assertEqual(revisions, expected)
+        expected = [('1', '1', 0), ('2', '2', 0), ('3c', '3', 0),
+            ('3a', '2.2.1', 1), ('3b', '2.1.1', 1), ('4b', '4', 0),
+            ('4a', '2.1.2', 1)]
+        self.assertEqual(expected, revisions)
         revisions = list(get_view_revisions(mainline_revs, rev_nos, wt.branch,
                                              'forward', include_merges=False))
-        self.assertEqual(revisions, [('1', 1, 0), ('2', 2, 0), ('3c', 3, 0),
-                                     ('4b', 4, 0)])
+        self.assertEqual([('1', '1', 0), ('2', '2', 0), ('3c', '3', 0),
+            ('4b', '4', 0)],
+            revisions)

=== modified file 'bzrlib/tests/test_memorytree.py'
--- bzrlib/tests/test_memorytree.py	2006-09-18 05:38:58 +0000
+++ bzrlib/tests/test_memorytree.py	2006-10-15 15:55:32 +0000
@@ -86,7 +86,8 @@
         branch = self.make_branch('branch')
         tree = MemoryTree.create_on_branch(branch)
         tree.lock_write()
-        tree.add(['afile', 'adir'], None, ['file', 'directory'])
+        tree.add(['', 'afile', 'adir'], None, 
+                 ['directory', 'file', 'directory'])
         self.assertEqual('afile', tree.id2path(tree.path2id('afile')))
         self.assertEqual('adir', tree.id2path(tree.path2id('adir')))
         self.assertFalse(tree.has_filename('afile'))
@@ -97,7 +98,8 @@
         branch = self.make_branch('branch')
         tree = MemoryTree.create_on_branch(branch)
         tree.lock_write()
-        tree.add(['foo'], ids=['foo-id'], kinds=['file'])
+        tree.add(['', 'foo'], ids=['root-id', 'foo-id'], 
+                  kinds=['directory', 'file'])
         tree.put_file_bytes_non_atomic('foo-id', 'barshoom')
         self.assertEqual('barshoom', tree.get_file('foo-id').read())
         tree.unlock()
@@ -106,7 +108,8 @@
         branch = self.make_branch('branch')
         tree = MemoryTree.create_on_branch(branch)
         tree.lock_write()
-        tree.add(['foo'], ids=['foo-id'], kinds=['file'])
+        tree.add(['', 'foo'], ids=['root-id', 'foo-id'], 
+                 kinds=['directory', 'file'])
         tree.put_file_bytes_non_atomic('foo-id', 'first-content')
         tree.put_file_bytes_non_atomic('foo-id', 'barshoom')
         self.assertEqual('barshoom', tree.get_file('foo-id').read())
@@ -121,7 +124,8 @@
         branch = self.make_branch('branch')
         tree = MemoryTree.create_on_branch(branch)
         tree.lock_write()
-        tree.add(['foo'], ids=['foo-id'], kinds=['file'])
+        tree.add(['', 'foo'], ids=['root-id', 'foo-id'], 
+                 kinds=['directory', 'file'])
         tree.put_file_bytes_non_atomic('foo-id', 'barshoom')
         revision_id = tree.commit('message baby')
         # the parents list for the tree should have changed.
@@ -136,7 +140,8 @@
         branch = self.make_branch('branch')
         tree = MemoryTree.create_on_branch(branch)
         tree.lock_write()
-        tree.add(['foo'], ids=['foo-id'], kinds=['file'])
+        tree.add(['', 'foo'], ids=['root-id', 'foo-id'], 
+                 kinds=['directory', 'file'])
         tree.unversion(['foo-id'])
         self.assertFalse(tree.has_id('foo-id'))
         tree.unlock()
@@ -144,5 +149,8 @@
     def test_last_revision(self):
         """There should be a last revision method we can call."""
         tree = self.make_branch_and_memory_tree('branch')
+        tree.lock_write()
+        tree.add('')
         rev_id = tree.commit('first post')
+        tree.unlock()
         self.assertEqual(rev_id, tree.last_revision())

=== modified file 'bzrlib/tests/test_merge.py'
--- bzrlib/tests/test_merge.py	2006-09-21 16:03:07 +0000
+++ bzrlib/tests/test_merge.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_merge3.py'
--- bzrlib/tests/test_merge3.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/test_merge3.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005 by Canonical Ltd
+# Copyright (C) 2004, 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_merge_core.py'
--- bzrlib/tests/test_merge_core.py	2006-10-06 05:53:44 +0000
+++ bzrlib/tests/test_merge_core.py	2006-10-16 01:50:48 +0000
@@ -1,3 +1,19 @@
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 import os
 import stat
 import sys
@@ -18,18 +34,20 @@
                             )
 from bzrlib.transform import TreeTransform
 from bzrlib.tests import TestCaseWithTransport, TestCase, TestSkipped
-from bzrlib.workingtree import WorkingTree
+from bzrlib.workingtree import WorkingTree, gen_root_id
 
 
 class MergeBuilder(object):
     def __init__(self, dir=None):
         self.dir = osutils.mkdtemp(prefix="merge-test", dir=dir)
+        self.tree_root = gen_root_id()
         def wt(name):
            path = pathjoin(self.dir, name)
            os.mkdir(path)
            wt = bzrlib.bzrdir.BzrDir.create_standalone_workingtree(path)
            # the tests perform pulls, so need a branch that is writeable.
            wt.lock_write()
+           wt.set_root_id(self.tree_root)
            tt = TreeTransform(wt)
            return wt, tt
         self.base, self.base_tt = wt('base')
@@ -182,16 +200,16 @@
     def test_change_name(self):
         """Test renames"""
         builder = MergeBuilder(getcwd())
-        builder.add_file("1", "TREE_ROOT", "name1", "hello1", True)
+        builder.add_file("1", builder.tree_root, "name1", "hello1", True)
         builder.change_name("1", other="name2")
-        builder.add_file("2", "TREE_ROOT", "name3", "hello2", True)
+        builder.add_file("2", builder.tree_root, "name3", "hello2", True)
         builder.change_name("2", base="name4")
-        builder.add_file("3", "TREE_ROOT", "name5", "hello3", True)
+        builder.add_file("3", builder.tree_root, "name5", "hello3", True)
         builder.change_name("3", this="name6")
         builder.merge()
         builder.cleanup()
         builder = MergeBuilder(getcwd())
-        builder.add_file("1", "TREE_ROOT", "name1", "hello1", False)
+        builder.add_file("1", builder.tree_root, "name1", "hello1", False)
         builder.change_name("1", other="name2", this="name3")
         conflicts = builder.merge()
         self.assertEqual(conflicts, [PathConflict('name3', 'name2', '1')])
@@ -199,9 +217,9 @@
 
     def test_merge_one(self):
         builder = MergeBuilder(getcwd())
-        builder.add_file("1", "TREE_ROOT", "name1", "hello1", True)
+        builder.add_file("1", builder.tree_root, "name1", "hello1", True)
         builder.change_contents("1", other="text4")
-        builder.add_file("2", "TREE_ROOT", "name2", "hello1", True)
+        builder.add_file("2", builder.tree_root, "name2", "hello1", True)
         builder.change_contents("2", other="text4")
         builder.merge(interesting_ids=["1"])
         self.assertEqual(builder.this.get_file("1").read(), "text4" )
@@ -211,8 +229,8 @@
     def test_file_moves(self):
         """Test moves"""
         builder = MergeBuilder(getcwd())
-        builder.add_dir("1", "TREE_ROOT", "dir1")
-        builder.add_dir("2", "TREE_ROOT", "dir2")
+        builder.add_dir("1", builder.tree_root, "dir1")
+        builder.add_dir("2", builder.tree_root, "dir2")
         builder.add_file("3", "1", "file1", "hello1", True)
         builder.add_file("4", "1", "file2", "hello2", True)
         builder.add_file("5", "1", "file3", "hello3", True)
@@ -223,9 +241,9 @@
         builder.cleanup()
 
         builder = MergeBuilder(getcwd())
-        builder.add_dir("1", "TREE_ROOT", "dir1")
-        builder.add_dir("2", "TREE_ROOT", "dir2")
-        builder.add_dir("3", "TREE_ROOT", "dir3")
+        builder.add_dir("1", builder.tree_root, "dir1")
+        builder.add_dir("2", builder.tree_root, "dir2")
+        builder.add_dir("3", builder.tree_root, "dir3")
         builder.add_file("4", "1", "file1", "hello1", False)
         builder.change_parent("4", other="2", this="3")
         conflicts = builder.merge()
@@ -252,7 +270,7 @@
     def test_reprocess_weave(self):
         # Reprocess works on weaves, and behaves as expected
         builder = MergeBuilder(getcwd())
-        builder.add_file('a', 'TREE_ROOT', 'blah', 'a', False)
+        builder.add_file('a', builder.tree_root, 'blah', 'a', False)
         builder.change_contents('a', this='b\nc\nd\ne\n', other='z\nc\nd\ny\n')
         builder.merge(WeaveMerger, reprocess=True)
         expected = """<<<<<<< TREE
@@ -279,14 +297,15 @@
 
     def contents_test_success(self, merge_factory):
         builder = MergeBuilder(getcwd())
-        builder.add_file("1", "TREE_ROOT", "name1", "text1", True)
+        builder.add_file("1", builder.tree_root, "name1", "text1", True)
         builder.change_contents("1", other="text4")
-        builder.add_file("2", "TREE_ROOT", "name3", "text2", False)
+        builder.add_file("2", builder.tree_root, "name3", "text2", False)
         builder.change_contents("2", base="text5")
-        builder.add_file("3", "TREE_ROOT", "name5", "text3", True)
-        builder.add_file("4", "TREE_ROOT", "name6", "text4", True)
+        builder.add_file("3", builder.tree_root, "name5", "text3", True)
+        builder.add_file("4", builder.tree_root, "name6", "text4", True)
         builder.remove_file("4", base=True)
-        builder.add_file("5", "TREE_ROOT", "name7", "a\nb\nc\nd\ne\nf\n", True)
+        builder.add_file("5", builder.tree_root, "name7", "a\nb\nc\nd\ne\nf\n",
+                         True)
         builder.change_contents("5", other="a\nz\nc\nd\ne\nf\n", 
                                      this="a\nb\nc\nd\ne\nz\n")
         conflicts = builder.merge(merge_factory)
@@ -306,11 +325,11 @@
 
     def contents_test_conflicts(self, merge_factory):
         builder = MergeBuilder(getcwd())
-        builder.add_file("1", "TREE_ROOT", "name1", "text1", True)
+        builder.add_file("1", builder.tree_root, "name1", "text1", True)
         builder.change_contents("1", other="text4", this="text3")
-        builder.add_file("2", "TREE_ROOT", "name2", "text1", True)
+        builder.add_file("2", builder.tree_root, "name2", "text1", True)
         builder.change_contents("2", other="\x00", this="text3")
-        builder.add_file("3", "TREE_ROOT", "name3", "text5", False)
+        builder.add_file("3", builder.tree_root, "name3", "text5", False)
         builder.change_perms("3", this=True)
         builder.change_contents('3', this='moretext')
         builder.remove_file('3', other=True)
@@ -324,7 +343,7 @@
     def test_symlink_conflicts(self):
         if sys.platform != "win32":
             builder = MergeBuilder(getcwd())
-            builder.add_symlink("2", "TREE_ROOT", "name2", "target1")
+            builder.add_symlink("2", builder.tree_root, "name2", "target1")
             builder.change_target("2", other="target4", base="text3")
             conflicts = builder.merge()
             self.assertEqual(conflicts, [ContentsConflict('name2', 
@@ -334,9 +353,9 @@
     def test_symlink_merge(self):
         if sys.platform != "win32":
             builder = MergeBuilder(getcwd())
-            builder.add_symlink("1", "TREE_ROOT", "name1", "target1")
-            builder.add_symlink("2", "TREE_ROOT", "name2", "target1")
-            builder.add_symlink("3", "TREE_ROOT", "name3", "target1")
+            builder.add_symlink("1", builder.tree_root, "name1", "target1")
+            builder.add_symlink("2", builder.tree_root, "name2", "target1")
+            builder.add_symlink("3", builder.tree_root, "name3", "target1")
             builder.change_target("1", this="target2")
             builder.change_target("2", base="target2")
             builder.change_target("3", other="target2")
@@ -348,20 +367,20 @@
 
     def test_no_passive_add(self):
         builder = MergeBuilder(getcwd())
-        builder.add_file("1", "TREE_ROOT", "name1", "text1", True)
+        builder.add_file("1", builder.tree_root, "name1", "text1", True)
         builder.remove_file("1", this=True)
         builder.merge()
         builder.cleanup()
 
     def test_perms_merge(self):
         builder = MergeBuilder(getcwd())
-        builder.add_file("1", "TREE_ROOT", "name1", "text1", True)
+        builder.add_file("1", builder.tree_root, "name1", "text1", True)
         builder.change_perms("1", other=False)
-        builder.add_file("2", "TREE_ROOT", "name2", "text2", True)
+        builder.add_file("2", builder.tree_root, "name2", "text2", True)
         builder.change_perms("2", base=False)
-        builder.add_file("3", "TREE_ROOT", "name3", "text3", True)
+        builder.add_file("3", builder.tree_root, "name3", "text3", True)
         builder.change_perms("3", this=False)
-        builder.add_file('4', 'TREE_ROOT', 'name4', 'text4', False)
+        builder.add_file('4', builder.tree_root, 'name4', 'text4', False)
         builder.change_perms('4', this=True)
         builder.remove_file('4', base=True)
         builder.merge()
@@ -372,19 +391,19 @@
 
     def test_new_suffix(self):
         builder = MergeBuilder(getcwd())
-        builder.add_file("1", "TREE_ROOT", "name1", "text1", True)
+        builder.add_file("1", builder.tree_root, "name1", "text1", True)
         builder.change_contents("1", other="text3")
-        builder.add_file("2", "TREE_ROOT", "name1.new", "text2", True)
+        builder.add_file("2", builder.tree_root, "name1.new", "text2", True)
         builder.merge()
         os.lstat(builder.this.id2abspath("2"))
         builder.cleanup()
 
     def test_spurious_conflict(self):
         builder = MergeBuilder(getcwd())
-        builder.add_file("1", "TREE_ROOT", "name1", "text1", False)
+        builder.add_file("1", builder.tree_root, "name1", "text1", False)
         builder.remove_file("1", other=True)
-        builder.add_file("2", "TREE_ROOT", "name1", "text1", False, this=False, 
-                         base=False)
+        builder.add_file("2", builder.tree_root, "name1", "text1", False, 
+                         this=False, base=False)
         conflicts = builder.merge()
         self.assertEqual(conflicts, []) 
         builder.cleanup()

=== modified file 'bzrlib/tests/test_missing.py'
--- bzrlib/tests/test_missing.py	2006-06-07 17:23:59 +0000
+++ bzrlib/tests/test_missing.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_msgeditor.py'
--- bzrlib/tests/test_msgeditor.py	2006-09-08 18:46:29 +0000
+++ bzrlib/tests/test_msgeditor.py	2006-10-11 23:08:27 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/tests/test_nonascii.py'
--- bzrlib/tests/test_nonascii.py	2006-07-11 15:05:36 +0000
+++ bzrlib/tests/test_nonascii.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_options.py'
--- bzrlib/tests/test_options.py	2006-08-16 13:13:39 +0000
+++ bzrlib/tests/test_options.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,18 @@
 # Copyright (C) 2005, 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from bzrlib.builtins import cmd_commit, cmd_log, cmd_status
 from bzrlib.commands import Command, parse_args

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2006-10-06 05:53:44 +0000
+++ bzrlib/tests/test_osutils.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_patch.py'
--- bzrlib/tests/test_patch.py	2006-04-16 17:49:14 +0000
+++ bzrlib/tests/test_patch.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_patches.py'
--- bzrlib/tests/test_patches.py	2006-05-30 03:51:03 +0000
+++ bzrlib/tests/test_patches.py	2006-10-11 23:32:09 +0000
@@ -1,19 +1,19 @@
-# Copyright (C) 2004 - 2006 Aaron Bentley
+# Copyright (C) 2004 - 2006 Aaron Bentley, Canonical Ltd
 # <aaron.bentley@utoronto.ca>
 #
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
 import unittest

=== modified file 'bzrlib/tests/test_permissions.py'
--- bzrlib/tests/test_permissions.py	2006-09-09 18:52:57 +0000
+++ bzrlib/tests/test_permissions.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/test_plugins.py'
--- bzrlib/tests/test_plugins.py	2006-09-25 21:54:28 +0000
+++ bzrlib/tests/test_plugins.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -9,12 +9,11 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-
 """Tests for plugins"""
 
 # XXX: There are no plugin tests at the moment because the plugin module

=== modified file 'bzrlib/tests/test_progress.py'
--- bzrlib/tests/test_progress.py	2006-07-10 23:00:44 +0000
+++ bzrlib/tests/test_progress.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_read_bundle.py'
--- bzrlib/tests/test_read_bundle.py	2006-09-08 00:19:48 +0000
+++ bzrlib/tests/test_read_bundle.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_reconcile.py'
--- bzrlib/tests/test_reconcile.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/test_reconcile.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_registry.py'
--- bzrlib/tests/test_registry.py	2006-09-21 22:25:19 +0000
+++ bzrlib/tests/test_registry.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_revert.py'
--- bzrlib/tests/test_revert.py	2006-09-27 20:28:32 +0000
+++ bzrlib/tests/test_revert.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_revision.py'
--- bzrlib/tests/test_revision.py	2006-09-05 08:14:23 +0000
+++ bzrlib/tests/test_revision.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# (C) 2005 Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_revisionnamespaces.py'
--- bzrlib/tests/test_revisionnamespaces.py	2006-08-28 16:19:47 +0000
+++ bzrlib/tests/test_revisionnamespaces.py	2006-10-16 10:03:21 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005, 2006 by Canonical Ltd
+# Copyright (C) 2004, 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,8 +22,8 @@
     errors,
     )
 from bzrlib.builtins import merge
-from bzrlib.tests import TestCaseWithTransport
-from bzrlib.revisionspec import RevisionSpec
+from bzrlib.tests import TestCase, TestCaseWithTransport
+from bzrlib.revisionspec import RevisionSpec, RevisionSpec_revno
 
 
 def spec_in_history(spec, branch):
@@ -36,6 +36,10 @@
 
     def setUp(self):
         super(TestRevisionSpec, self).setUp()
+        # this sets up a revision graph:
+        # r1: []             1
+        # alt_r2: [r1]       1.1.1
+        # r2: [r1, alt_r2]   2
 
         self.tree = self.make_branch_and_tree('tree')
         self.build_tree(['tree/a'])
@@ -90,15 +94,30 @@
                           RevisionSpec.from_string, '123a')
 
 
+
+class TestRevnoFromString(TestCase):
+
+    def test_from_string_dotted_decimal(self):
+        self.assertRaises(errors.NoSuchRevisionSpec, RevisionSpec.from_string, '-1.1')
+        self.assertRaises(errors.NoSuchRevisionSpec, RevisionSpec.from_string, '.1')
+        self.assertRaises(errors.NoSuchRevisionSpec, RevisionSpec.from_string, '1..1')
+        self.assertRaises(errors.NoSuchRevisionSpec, RevisionSpec.from_string, '1.2..1')
+        self.assertRaises(errors.NoSuchRevisionSpec, RevisionSpec.from_string, '1.')
+        self.assertIsInstance(RevisionSpec.from_string('1.1'), RevisionSpec_revno)
+        self.assertIsInstance(RevisionSpec.from_string('1.1.3'), RevisionSpec_revno)
+
+
 class TestRevisionSpec_revno(TestRevisionSpec):
 
     def test_positive_int(self):
         self.assertInHistoryIs(0, None, '0')
         self.assertInHistoryIs(1, 'r1', '1')
         self.assertInHistoryIs(2, 'r2', '2')
-
         self.assertInvalid('3')
 
+    def test_dotted_decimal(self):
+        self.assertInHistoryIs(None, 'alt_r2', '1.1.1')
+
     def test_negative_int(self):
         self.assertInHistoryIs(2, 'r2', '-1')
         self.assertInHistoryIs(1, 'r1', '-2')

=== modified file 'bzrlib/tests/test_revisiontree.py'
--- bzrlib/tests/test_revisiontree.py	2006-09-07 23:13:08 +0000
+++ bzrlib/tests/test_revisiontree.py	2006-09-30 00:25:31 +0000
@@ -17,6 +17,9 @@
 
 """Tests for the RevisionTree class."""
 
+from bzrlib import (
+    revision,
+    )
 import bzrlib
 from bzrlib.tests import TestCaseWithTransport
 from bzrlib.tree import RevisionTree
@@ -51,3 +54,8 @@
         # the parents for a revision_tree(None) are []:
         self.assertEqual([],
             self.t.branch.repository.revision_tree(None).get_parent_ids())
+
+    def test_empty_no_root(self):
+        null_tree = self.t.branch.repository.revision_tree(
+            revision.NULL_REVISION)
+        self.assertIs(None, null_tree.inventory.root)

=== modified file 'bzrlib/tests/test_rio.py'
--- bzrlib/tests/test_rio.py	2006-09-22 19:37:57 +0000
+++ bzrlib/tests/test_rio.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_sampler.py'
--- bzrlib/tests/test_sampler.py	2006-01-05 10:49:26 +0000
+++ bzrlib/tests/test_sampler.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2006-10-13 10:50:33 +0000
+++ bzrlib/tests/test_selftest.py	2006-10-17 14:01:12 +0000
@@ -1,8 +1,9 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of

=== modified file 'bzrlib/tests/test_setup.py'
--- bzrlib/tests/test_setup.py	2006-09-09 16:43:09 +0000
+++ bzrlib/tests/test_setup.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_smart_add.py'
--- bzrlib/tests/test_smart_add.py	2006-09-07 21:37:43 +0000
+++ bzrlib/tests/test_smart_add.py	2006-09-10 19:04:48 +0000
@@ -319,14 +319,12 @@
 
         self.build_tree(['new/a', 'new/b', 'new/c',
                          'new/subdir/', 'new/subdir/b', 'new/subdir/d'])
+        new_tree.set_root_id(self.base_tree.get_root_id())
         self.add_helper(self.base_tree, 'dir', new_tree, ['new'])
 
-        # We 'a' and 'b' exist in the root, and they are being added
-        # in a new 'root'. Since ROOT ids are not unique, we will
+        # We know 'a' and 'b' exist in the root, and they are being added
+        # in a new 'root'. Since ROOT ids have been set as the same, we will
         # use those ids
-        # TODO: This will probably change once trees have a unique root id
-        # It is definitely arguable that 'a' should get the id of
-        # 'dir/a' not of 'a'.
         self.assertEqual(self.base_tree.path2id('a'),
                          new_tree.path2id('a'))
         self.assertEqual(self.base_tree.path2id('b'),

=== modified file 'bzrlib/tests/test_source.py'
--- bzrlib/tests/test_source.py	2006-06-20 05:32:16 +0000
+++ bzrlib/tests/test_source.py	2006-10-16 02:29:21 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -22,14 +22,39 @@
 
 # import system imports here
 import os
+import re
 import sys
 
 #import bzrlib specific imports here
-from bzrlib.tests import TestCase
+from bzrlib import (
+    osutils,
+    )
 import bzrlib.branch
-
-
-class TestApiUsage(TestCase):
+from bzrlib.tests import TestCase, TestSkipped
+
+
+# Files which are listed here will be skipped when testing for Copyright (or
+# GPL) statements.
+COPYRIGHT_EXCEPTIONS = ['bzrlib/lsprof.py']
+
+LICENSE_EXCEPTIONS = ['bzrlib/lsprof.py']
+# Technically, 'bzrlib/lsprof.py' should be 'bzrlib/util/lsprof.py',
+# (we do not check bzrlib/util/, since that is code bundled from elsewhere)
+# but for compatibility with previous releases, we don't want to move it.
+
+
+class TestSourceHelper(TestCase):
+
+    def source_file_name(self, package):
+        """Return the path of the .py file for package."""
+        path = package.__file__
+        if path[-1] in 'co':
+            return path[:-1]
+        else:
+            return path
+
+
+class TestApiUsage(TestSourceHelper):
 
     def find_occurences(self, rule, filename):
         """Find the number of occurences of rule in a file."""
@@ -40,14 +65,6 @@
                 occurences += 1
         return occurences
 
-    def source_file_name(self, package):
-        """Return the path of the .py file for package."""
-        path = package.__file__
-        if path[-1] in 'co':
-            return path[:-1]
-        else:
-            return path
-
     def test_branch_working_tree(self):
         """Test that the number of uses of working_tree in branch is stable."""
         occurences = self.find_occurences('self.working_tree()',
@@ -73,3 +90,152 @@
         # drops, it is not given a buffer but rather this test updated
         # immediately.
         self.assertEqual(2, occurences)
+
+
+class TestSource(TestSourceHelper):
+
+    def get_bzrlib_dir(self):
+        """Get the path to the root of bzrlib"""
+        source = self.source_file_name(bzrlib)
+        source_dir = os.path.dirname(source)
+
+        # Avoid the case when bzrlib is packaged in a zip file
+        if not os.path.isdir(source_dir):
+            raise TestSkipped('Cannot find bzrlib source directory. Expected %s'
+                              % source_dir)
+        return source_dir
+
+    def get_source_files(self):
+        """yield all source files for bzr and bzrlib"""
+        bzrlib_dir = self.get_bzrlib_dir()
+
+        # This is the front-end 'bzr' script
+        bzr_path = self.get_bzr_path()
+        yield bzr_path
+
+        for root, dirs, files in os.walk(bzrlib_dir):
+            for f in files:
+                if not f.endswith('.py'):
+                    continue
+                yield osutils.pathjoin(root, f)
+
+    def get_source_file_contents(self):
+        for fname in self.get_source_files():
+            f = open(fname, 'rb')
+            try:
+                text = f.read()
+            finally:
+                f.close()
+            yield fname, text
+
+    def is_copyright_exception(self, fname):
+        """Certain files are allowed to be different"""
+        if '/util/' in fname:
+            # We don't require external utilities to be (C) Canonical Ltd
+            return True
+
+        for exc in COPYRIGHT_EXCEPTIONS:
+            if fname.endswith(exc):
+                return True
+
+        return False
+
+    def is_license_exception(self, fname):
+        """Certain files are allowed to be different"""
+        if '/util/' in fname:
+            # We don't require external utilities to be (C) Canonical Ltd
+            return True
+
+        for exc in LICENSE_EXCEPTIONS:
+            if fname.endswith(exc):
+                return True
+
+        return False
+
+    def test_copyright(self):
+        """Test that all .py files have a valid copyright statement"""
+        # These are files which contain a different copyright statement
+        # and that is okay.
+        incorrect = []
+
+        copyright_re = re.compile('#\\s*copyright.*(?=\n)', re.I)
+        copyright_canonical_re = re.compile(
+            r'# Copyright \(C\) ' # Opening "# Copyright (C)"
+            r'(\d+)(, \d+)*' # Followed by a series of dates
+            r'.*Canonical Ltd' # And containing 'Canonical Ltd'
+            )
+
+        for fname, text in self.get_source_file_contents():
+            if self.is_copyright_exception(fname):
+                continue
+            match = copyright_canonical_re.search(text)
+            if not match:
+                match = copyright_re.search(text)
+                if match:
+                    incorrect.append((fname, 'found: %s' % (match.group(),)))
+                else:
+                    incorrect.append((fname, 'no copyright line found\n'))
+            else:
+                if 'by Canonical' in match.group():
+                    incorrect.append((fname,
+                        'should not have: "by Canonical": %s'
+                        % (match.group(),)))
+
+        if incorrect:
+            help_text = ["Some files have missing or incorrect copyright"
+                         " statements.",
+                         "",
+                         "Please either add them to the list of"
+                         " COPYRIGHT_EXCEPTIONS in"
+                         " bzrlib/tests/test_source.py",
+                         # this is broken to prevent a false match
+                         "or add '# Copyright (C)"
+                         " 2006 Canonical Ltd' to these files:",
+                         "",
+                        ]
+            for fname, comment in incorrect:
+                help_text.append(fname)
+                help_text.append((' '*4) + comment)
+
+            self.fail('\n'.join(help_text))
+
+    def test_gpl(self):
+        """Test that all .py files have a GPL disclaimer"""
+        incorrect = []
+
+        gpl_txt = """
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+"""
+        gpl_re = re.compile(re.escape(gpl_txt), re.MULTILINE)
+
+        for fname, text in self.get_source_file_contents():
+            if self.is_license_exception(fname):
+                continue
+            if not gpl_re.search(text):
+                incorrect.append(fname)
+
+        if incorrect:
+            help_text = ['Some files have missing or incomplete GPL statement',
+                         "",
+                         "Please either add them to the list of"
+                         " LICENSE_EXCEPTIONS in"
+                         " bzrlib/tests/test_source.py",
+                         "Or add the following text to the beginning:",
+                         gpl_txt
+                        ]
+            for fname in incorrect:
+                help_text.append((' '*4) + fname)
+
+            self.fail('\n'.join(help_text))

=== modified file 'bzrlib/tests/test_status.py'
--- bzrlib/tests/test_status.py	2006-09-04 08:00:00 +0000
+++ bzrlib/tests/test_status.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Development Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_store.py'
--- bzrlib/tests/test_store.py	2006-09-05 20:58:28 +0000
+++ bzrlib/tests/test_store.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Development Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_symbol_versioning.py'
--- bzrlib/tests/test_symbol_versioning.py	2006-09-05 21:35:51 +0000
+++ bzrlib/tests/test_symbol_versioning.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/test_testament.py'
--- bzrlib/tests/test_testament.py	2006-09-26 13:28:39 +0000
+++ bzrlib/tests/test_testament.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
     def setUp(self):
         super(TestamentSetup, self).setUp()
         self.wt = self.make_branch_and_tree('.')
+        self.wt.set_root_id('TREE_ROT')
         b = self.b = self.wt.branch
         b.nick = "test branch"
         self.wt.commit(message='initial null commit',
@@ -201,7 +202,7 @@
 message:
   initial null commit
 inventory:
-  directory . TREE_ROOT test@user-1 no
+  directory . TREE_ROT test@user-1 no
 properties:
   branch-nick:
     test branch
@@ -280,7 +281,7 @@
 message:
   add files and directories
 inventory:
-  directory . TREE_ROOT test@user-2 no
+  directory . TREE_ROT test@user-2 no
   file hello hello-id 34dd0ac19a24bf80c4d33b5c8960196e8d8d1f73 test@user-2 yes
   directory src src-id test@user-2 no
   file src/foo.c foo.c-id a2a049c20f908ae31b231d98779eb63c66448f24 test@user-2 no
@@ -374,7 +375,7 @@
 message:
   revision with properties
 inventory:
-  directory . TREE_ROOT test@user-3 no
+  directory . TREE_ROT test@user-3 no
   file hello hello-id 34dd0ac19a24bf80c4d33b5c8960196e8d8d1f73 test@user-2 yes
   directory src src-id test@user-2 no
   file src/foo.c foo.c-id a2a049c20f908ae31b231d98779eb63c66448f24 test@user-2 no
@@ -443,7 +444,7 @@
 message:
   add symlink
 inventory:
-  directory . TREE_ROOT test@user-3 no
+  directory . TREE_ROT test@user-3 no
   file hello hello-id 34dd0ac19a24bf80c4d33b5c8960196e8d8d1f73 test@user-2 yes
   symlink link link-id wibble/linktarget test@user-3 no
   directory src src-id test@user-2 no
@@ -509,7 +510,7 @@
 message:
   non-ascii commit \N{COPYRIGHT SIGN} me
 inventory:
-  directory . TREE_ROOT test@user-3 no
+  directory . TREE_ROT test@user-3 no
   file hello hello-id 34dd0ac19a24bf80c4d33b5c8960196e8d8d1f73 test@user-2 yes
   directory src src-id test@user-2 no
   file src/foo.c foo.c-id a2a049c20f908ae31b231d98779eb63c66448f24 test@user-2 no

=== modified file 'bzrlib/tests/test_textfile.py'
--- bzrlib/tests/test_textfile.py	2006-06-20 03:57:11 +0000
+++ bzrlib/tests/test_textfile.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_trace.py'
--- bzrlib/tests/test_trace.py	2006-09-06 21:17:22 +0000
+++ bzrlib/tests/test_trace.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_transactions.py'
--- bzrlib/tests/test_transactions.py	2006-06-06 12:06:20 +0000
+++ bzrlib/tests/test_transactions.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/test_transform.py'
--- bzrlib/tests/test_transform.py	2006-09-21 20:21:36 +0000
+++ bzrlib/tests/test_transform.py	2006-09-27 02:28:44 +0000
@@ -35,6 +35,7 @@
 from bzrlib.transform import (TreeTransform, ROOT_PARENT, FinalPaths, 
                               resolve_conflicts, cook_conflicts, 
                               find_interesting, build_tree, get_backup_name)
+from bzrlib.workingtree import gen_root_id
 
 
 class TestTreeTransform(TestCaseInTempDir):
@@ -47,7 +48,7 @@
     def get_transform(self):
         transform = TreeTransform(self.wt)
         #self.addCleanup(transform.finalize)
-        return transform, transform.trans_id_tree_file_id(self.wt.get_root_id())
+        return transform, transform.root
 
     def test_existing_limbo(self):
         limbo_name = urlutils.local_path_from_url(
@@ -197,7 +198,7 @@
         transform3.delete_contents(oz_id)
         self.assertEqual(transform3.find_conflicts(), 
                          [('missing parent', oz_id)])
-        root_id = transform3.trans_id_tree_file_id('TREE_ROOT')
+        root_id = transform3.root
         tip_id = transform3.trans_id_tree_file_id('tip-id')
         transform3.adjust_path('tip', root_id, tip_id)
         transform3.apply()
@@ -229,7 +230,7 @@
     def test_name_invariants(self):
         create_tree, root = self.get_transform()
         # prepare tree
-        root = create_tree.trans_id_tree_file_id('TREE_ROOT')
+        root = create_tree.root
         create_tree.new_file('name1', root, 'hello1', 'name1')
         create_tree.new_file('name2', root, 'hello2', 'name2')
         ddir = create_tree.new_directory('dying_directory', root, 'ddir')
@@ -239,7 +240,7 @@
         create_tree.apply()
 
         mangle_tree,root = self.get_transform()
-        root = mangle_tree.trans_id_tree_file_id('TREE_ROOT')
+        root = mangle_tree.root
         #swap names
         name1 = mangle_tree.trans_id_tree_file_id('name1')
         name2 = mangle_tree.trans_id_tree_file_id('name2')
@@ -324,7 +325,7 @@
     def test_move_dangling_ie(self):
         create_tree, root = self.get_transform()
         # prepare tree
-        root = create_tree.trans_id_tree_file_id('TREE_ROOT')
+        root = create_tree.root
         create_tree.new_file('name1', root, 'hello1', 'name1')
         create_tree.apply()
         delete_contents, root = self.get_transform()
@@ -340,7 +341,7 @@
     def test_replace_dangling_ie(self):
         create_tree, root = self.get_transform()
         # prepare tree
-        root = create_tree.trans_id_tree_file_id('TREE_ROOT')
+        root = create_tree.root
         create_tree.new_file('name1', root, 'hello1', 'name1')
         create_tree.apply()
         delete_contents = TreeTransform(self.wt)
@@ -587,10 +588,11 @@
 
 
 class TransformGroup(object):
-    def __init__(self, dirname):
+    def __init__(self, dirname, root_id):
         self.name = dirname
         os.mkdir(dirname)
         self.wt = BzrDir.create_standalone_workingtree(dirname)
+        self.wt.set_root_id(root_id)
         self.b = self.wt.branch
         self.tt = TreeTransform(self.wt)
         self.root = self.tt.trans_id_tree_file_id(self.wt.get_root_id())
@@ -602,7 +604,8 @@
 
 class TestTransformMerge(TestCaseInTempDir):
     def test_text_merge(self):
-        base = TransformGroup("base")
+        root_id = gen_root_id()
+        base = TransformGroup("base", root_id)
         base.tt.new_file('a', base.root, 'a\nb\nc\nd\be\n', 'a')
         base.tt.new_file('b', base.root, 'b1', 'b')
         base.tt.new_file('c', base.root, 'c', 'c')
@@ -612,7 +615,7 @@
         base.tt.new_directory('g', base.root, 'g')
         base.tt.new_directory('h', base.root, 'h')
         base.tt.apply()
-        other = TransformGroup("other")
+        other = TransformGroup("other", root_id)
         other.tt.new_file('a', other.root, 'y\nb\nc\nd\be\n', 'a')
         other.tt.new_file('b', other.root, 'b2', 'b')
         other.tt.new_file('c', other.root, 'c2', 'c')
@@ -623,7 +626,7 @@
         other.tt.new_file('h', other.root, 'h\ni\nj\nk\n', 'h')
         other.tt.new_file('i', other.root, 'h\ni\nj\nk\n', 'i')
         other.tt.apply()
-        this = TransformGroup("this")
+        this = TransformGroup("this", root_id)
         this.tt.new_file('a', this.root, 'a\nb\nc\nd\bz\n', 'a')
         this.tt.new_file('b', this.root, 'b', 'b')
         this.tt.new_file('c', this.root, 'c', 'c')
@@ -680,9 +683,10 @@
     def test_file_merge(self):
         if not has_symlinks():
             raise TestSkipped('Symlinks are not supported on this platform')
-        base = TransformGroup("BASE")
-        this = TransformGroup("THIS")
-        other = TransformGroup("OTHER")
+        root_id = gen_root_id()
+        base = TransformGroup("BASE", root_id)
+        this = TransformGroup("THIS", root_id)
+        other = TransformGroup("OTHER", root_id)
         for tg in this, base, other:
             tg.tt.new_directory('a', tg.root, 'a')
             tg.tt.new_symlink('b', tg.root, 'b', 'b')
@@ -720,9 +724,10 @@
         self.assertIs(os.path.lexists(this.wt.abspath('h.OTHER')), True)
 
     def test_filename_merge(self):
-        base = TransformGroup("BASE")
-        this = TransformGroup("THIS")
-        other = TransformGroup("OTHER")
+        root_id = gen_root_id()
+        base = TransformGroup("BASE", root_id)
+        this = TransformGroup("THIS", root_id)
+        other = TransformGroup("OTHER", root_id)
         base_a, this_a, other_a = [t.tt.new_directory('a', t.root, 'a') 
                                    for t in [base, this, other]]
         base_b, this_b, other_b = [t.tt.new_directory('b', t.root, 'b') 
@@ -752,9 +757,10 @@
         self.assertEqual(this.wt.id2path('f'), pathjoin('b/f1'))
 
     def test_filename_merge_conflicts(self):
-        base = TransformGroup("BASE")
-        this = TransformGroup("THIS")
-        other = TransformGroup("OTHER")
+        root_id = gen_root_id()
+        base = TransformGroup("BASE", root_id)
+        this = TransformGroup("THIS", root_id)
+        other = TransformGroup("OTHER", root_id)
         base_a, this_a, other_a = [t.tt.new_directory('a', t.root, 'a') 
                                    for t in [base, this, other]]
         base_b, this_b, other_b = [t.tt.new_directory('b', t.root, 'b') 

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2006-10-12 14:29:32 +0000
+++ bzrlib/tests/test_transport.py	2006-10-17 14:01:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005, 2006 by Canonical Ltd
+# Copyright (C) 2004, 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -106,6 +106,10 @@
                          t._combine_paths('/home/sarah', 'project/foo'))
         self.assertEqual('/etc',
                          t._combine_paths('/home/sarah', '../../etc'))
+        self.assertEqual('/etc',
+                         t._combine_paths('/home/sarah', '../../../etc'))
+        self.assertEqual('/etc',
+                         t._combine_paths('/home/sarah', '/etc'))
 
 
 class TestCoalesceOffsets(TestCase):
@@ -186,8 +190,9 @@
         self.assertEqual("memory:///", transport.base)
         self.assertEqual("memory:///", transport.abspath('/'))
 
-    def test_relpath(self):
+    def test_abspath_of_relpath_starting_at_root(self):
         transport = MemoryTransport()
+        self.assertEqual("memory:///foo", transport.abspath('/foo'))
 
     def test_append_and_get(self):
         transport = MemoryTransport()

=== modified file 'bzrlib/tests/test_transport_implementations.py'
--- bzrlib/tests/test_transport_implementations.py	2006-10-13 15:53:16 +0000
+++ bzrlib/tests/test_transport_implementations.py	2006-10-17 14:01:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005, 2006 by Canonical Ltd
+# Copyright (C) 2004, 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1101,6 +1101,9 @@
         # the abspath of "/" and "/foo/.." should result in the same location
         self.assertEqual(transport.abspath("/"), transport.abspath("/foo/.."))
 
+        self.assertEqual(transport.clone("/").abspath('foo'),
+                         transport.abspath("/foo"))
+
     def test_local_abspath(self):
         transport = self.get_transport()
         try:

=== modified file 'bzrlib/tests/test_tree.py'
--- bzrlib/tests/test_tree.py	2006-09-26 13:28:39 +0000
+++ bzrlib/tests/test_tree.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -109,3 +109,12 @@
              ('compare', tree2, tree, 'unchanged', 'specific', 'extra',
               'require', True),
             ], RecordingOptimiser.calls)
+
+    def test_changes_from_with_root(self):
+        """Ensure the include_root option does what's expected."""
+        wt = self.make_branch_and_tree('.')
+        delta = wt.changes_from(wt.basis_tree())
+        self.assertEqual(len(delta.added), 0)
+        delta = wt.changes_from(wt.basis_tree(), wt, include_root=True)
+        self.assertEqual(len(delta.added), 1)
+        self.assertEqual(delta.added[0][0], '')

=== modified file 'bzrlib/tests/test_tsort.py'
--- bzrlib/tests/test_tsort.py	2006-03-28 14:29:13 +0000
+++ bzrlib/tests/test_tsort.py	2006-10-16 10:03:21 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -89,31 +89,41 @@
 class MergeSortTests(TestCase):
 
     def assertSortAndIterate(self, graph, branch_tip, result_list,
-            mainline_revisions=None):
+            generate_revno, mainline_revisions=None):
         """Check that merge based sorting and iter_topo_order on graph works."""
         self.assertEquals(result_list,
-            merge_sort(graph, branch_tip, mainline_revisions=mainline_revisions))
+            merge_sort(graph, branch_tip, mainline_revisions=mainline_revisions,
+                generate_revno=generate_revno))
         self.assertEqual(result_list,
             list(MergeSorter(
                 graph,
                 branch_tip,
-                mainline_revisions=mainline_revisions).iter_topo_order()))
+                mainline_revisions=mainline_revisions,
+                generate_revno=generate_revno,
+                ).iter_topo_order()))
 
     def test_merge_sort_empty(self):
         # sorting of an emptygraph does not error
-        self.assertSortAndIterate({}, None, [])
+        self.assertSortAndIterate({}, None, [], False)
+        self.assertSortAndIterate({}, None, [], True)
 
     def test_merge_sort_not_empty_no_tip(self):
         # merge sorting of a branch starting with None should result
         # in an empty list: no revisions are dragged in.
-        self.assertSortAndIterate({0: []}.items(), None, [])
+        self.assertSortAndIterate({0: []}.items(), None, [], False)
+        self.assertSortAndIterate({0: []}.items(), None, [], True)
 
     def test_merge_sort_one_revision(self):
         # sorting with one revision as the tip returns the correct fields:
         # sequence - 0, revision id, merge depth - 0, end_of_merge
         self.assertSortAndIterate({'id': []}.items(),
                                   'id',
-                                  [(0, 'id', 0, True)])
+                                  [(0, 'id', 0, True)],
+                                  False)
+        self.assertSortAndIterate({'id': []}.items(),
+                                  'id',
+                                  [(0, 'id', 0, (1,), True)],
+                                  True)
     
     def test_sequence_numbers_increase_no_merges(self):
         # emit a few revisions with no merges to check the sequence
@@ -126,7 +136,19 @@
             [(0, 'C', 0, False),
              (1, 'B', 0, False),
              (2, 'A', 0, True),
-             ]
+             ],
+            False
+            )
+        self.assertSortAndIterate(
+            {'A': [],
+             'B': ['A'],
+             'C': ['B']}.items(),
+            'C',
+            [(0, 'C', 0, (3,), False),
+             (1, 'B', 0, (2,), False),
+             (2, 'A', 0, (1,), True),
+             ],
+            True
             )
 
     def test_sequence_numbers_increase_with_merges(self):
@@ -139,7 +161,19 @@
             [(0, 'C', 0, False),
              (1, 'B', 1, True),
              (2, 'A', 0, True),
-             ]
+             ],
+            False
+            )
+        self.assertSortAndIterate(
+            {'A': [],
+             'B': ['A'],
+             'C': ['A', 'B']}.items(),
+            'C',
+            [(0, 'C', 0, (2,), False),
+             (1, 'B', 1, (1,1,1), True),
+             (2, 'A', 0, (1,), True),
+             ],
+            True
             )
         
     def test_merge_depth_with_nested_merges(self):
@@ -173,7 +207,30 @@
              (5, 'F', 2, True),
              (6, 'G', 1, True),
              (7, 'H', 0, True),
-             ]
+             ],
+            False
+            )
+        self.assertSortAndIterate(
+            {'A': ['D', 'B'],
+             'B': ['C', 'F'],
+             'C': ['H'],
+             'D': ['H', 'E'],
+             'E': ['G', 'F'],
+             'F': ['G'],
+             'G': ['H'],
+             'H': []
+             }.items(),
+            'A',
+            [(0, 'A', 0, (3,),  False),
+             (1, 'B', 1, (1,2,2), False),
+             (2, 'C', 1, (1,2,1), True),
+             (3, 'D', 0, (2,), False),
+             (4, 'E', 1, (1,1,2), False),
+             (5, 'F', 2, (1,1,1,1,1), True),
+             (6, 'G', 1, (1,1,1), True),
+             (7, 'H', 0, (1,), True),
+             ],
+            True
             )
  
     def test_end_of_merge_not_last_revision_in_branch(self):
@@ -186,7 +243,18 @@
             'A',
             [(0, 'A', 0, False),
              (1, 'B', 0, True)
-             ]
+             ],
+            False
+            )
+        self.assertSortAndIterate(
+            {'A': ['B'],
+             'B': [],
+             },
+            'A',
+            [(0, 'A', 0, (2,), False),
+             (1, 'B', 0, (1,), True)
+             ],
+            True
             )
 
     def test_end_of_merge_multiple_revisions_merged_at_once(self):
@@ -222,7 +290,30 @@
              (5, 'F', 2, True),
              (6, 'G', 1, True),
              (7, 'H', 0, True),
-             ]
+             ],
+            False
+            )
+        self.assertSortAndIterate(
+            {'A': ['H', 'B', 'E'],
+             'B': ['D', 'C'],
+             'C': ['D'],
+             'D': ['H'],
+             'E': ['G', 'F'],
+             'F': ['G'],
+             'G': ['H'],
+             'H': [],
+             },
+            'A',
+            [(0, 'A', 0, (2,), False),
+             (1, 'B', 1, (1,2,2), False),
+             (2, 'C', 2, (1,2,1,1,1), True),
+             (3, 'D', 1, (1,2,1), True),
+             (4, 'E', 1, (1,1,2), False),
+             (5, 'F', 2, (1,1,1,1,1), True),
+             (6, 'G', 1, (1,1,1), True),
+             (7, 'H', 0, (1,), True),
+             ],
+            True
             )
 
     def test_mainline_revs_partial(self):
@@ -252,6 +343,7 @@
         # C 1 
         # because C is brought in by B in this view and D
         # is the terminating revision id
+        # this should also preserve revision numbers: C should still be 2.1.1
         self.assertSortAndIterate(
             {'A': ['E', 'B'],
              'B': ['D', 'C'],
@@ -264,6 +356,22 @@
              (1, 'B', 0, False),
              (2, 'C', 1, True),
              ],
+            False,
+            mainline_revisions=['D', 'B', 'A']
+            )
+        self.assertSortAndIterate(
+            {'A': ['E', 'B'],
+             'B': ['D', 'C'],
+             'C': ['D'],
+             'D': ['E'],
+             'E': []
+             },
+            'A',
+            [(0, 'A', 0, (4,), False),
+             (1, 'B', 0, (3,), False),
+             (2, 'C', 1, (2,1,1), True),
+             ],
+            True,
             mainline_revisions=['D', 'B', 'A']
             )
 
@@ -276,6 +384,75 @@
             'A',
             [(0, 'A', 0, True),
              ],
+            False,
+            mainline_revisions=[None, 'A']
+            )
+        self.assertSortAndIterate(
+            {'A': [],
+             },
+            'A',
+            [(0, 'A', 0, (1,), True),
+             ],
+            True,
             mainline_revisions=[None, 'A']
             )
 
+    def test_parallel_root_sequence_numbers_increase_with_merges(self):
+        """When there are parallel roots, check their revnos."""
+        self.assertSortAndIterate(
+            {'A': [],
+             'B': [],
+             'C': ['A', 'B']}.items(),
+            'C',
+            [(0, 'C', 0, (2,), False),
+             (1, 'B', 1, (0,1,1), True),
+             (2, 'A', 0, (1,), True),
+             ],
+            True
+            )
+        
+    def test_revnos_are_globally_assigned(self):
+        """revnos are assigned according to the revision they derive from."""
+        # in this test we setup a number of branches that all derive from 
+        # the first revision, and then merge them one at a time, which 
+        # should give the revisions as they merge numbers still deriving from
+        # the revision were based on.
+        # merge 3: J: ['G', 'I']
+        # branch 3:
+        #  I: ['H']
+        #  H: ['A']
+        # merge 2: G: ['D', 'F']
+        # branch 2:
+        #  F: ['E']
+        #  E: ['A']
+        # merge 1: D: ['A', 'C']
+        # branch 1:
+        #  C: ['B']
+        #  B: ['A']
+        # root: A: []
+        self.assertSortAndIterate(
+            {'J': ['G', 'I'],
+             'I': ['H',],
+             'H': ['A'],
+             'G': ['D', 'F'],
+             'F': ['E'],
+             'E': ['A'],
+             'D': ['A', 'C'],
+             'C': ['B'],
+             'B': ['A'],
+             'A': [],
+             }.items(),
+            'J',
+            [(0, 'J', 0, (4,), False),
+             (1, 'I', 1, (1,3,2), False),
+             (2, 'H', 1, (1,3,1), True),
+             (3, 'G', 0, (3,), False),
+             (4, 'F', 1, (1,2,2), False),
+             (5, 'E', 1, (1,2,1), True),
+             (6, 'D', 0, (2,), False),
+             (7, 'C', 1, (1,1,2), False),
+             (8, 'B', 1, (1,1,1), True),
+             (9, 'A', 0, (1,), True),
+             ],
+            True
+            )

=== modified file 'bzrlib/tests/test_tuned_gzip.py'
--- bzrlib/tests/test_tuned_gzip.py	2006-06-20 03:57:11 +0000
+++ bzrlib/tests/test_tuned_gzip.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_ui.py'
--- bzrlib/tests/test_ui.py	2006-07-12 02:45:22 +0000
+++ bzrlib/tests/test_ui.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_upgrade.py'
--- bzrlib/tests/test_upgrade.py	2006-09-05 08:14:23 +0000
+++ bzrlib/tests/test_upgrade.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_urlutils.py'
--- bzrlib/tests/test_urlutils.py	2006-07-11 18:34:09 +0000
+++ bzrlib/tests/test_urlutils.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_version.py'
--- bzrlib/tests/test_version.py	2006-09-05 08:14:23 +0000
+++ bzrlib/tests/test_version.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005, 2006 by Canonical Ltd
+# Copyright (C) 2004, 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_version_info.py'
--- bzrlib/tests/test_version_info.py	2006-09-22 05:38:28 +0000
+++ bzrlib/tests/test_version_info.py	2006-09-27 02:28:44 +0000
@@ -112,8 +112,8 @@
         self.assertEqual(['False'], stanza.get_all('clean'))
 
         file_rev_stanza = get_one_stanza(stanza, 'file-revisions')
-        self.assertEqual(['a', 'b', 'c'], file_rev_stanza.get_all('path'))
-        self.assertEqual(['r3', 'r2', 'unversioned'],
+        self.assertEqual(['', 'a', 'b', 'c'], file_rev_stanza.get_all('path'))
+        self.assertEqual(['r3', 'r3', 'r2', 'unversioned'],
             file_rev_stanza.get_all('revision'))
         os.remove('branch/c')
 
@@ -129,8 +129,10 @@
         wt.rename_one('b', 'd')
         stanza = regen(check_for_clean=True, include_file_revisions=True)
         file_rev_stanza = get_one_stanza(stanza, 'file-revisions')
-        self.assertEqual(['a', 'b', 'c', 'd'], file_rev_stanza.get_all('path'))
-        self.assertEqual(['modified', 'renamed to d', 'new', 'renamed from b'],
+        self.assertEqual(['', 'a', 'b', 'c', 'd'], 
+                          file_rev_stanza.get_all('path'))
+        self.assertEqual(['r3', 'modified', 'renamed to d', 'new', 
+                          'renamed from b'],
                          file_rev_stanza.get_all('revision'))
 
         wt.commit('modified', rev_id='r4')
@@ -138,8 +140,8 @@
         os.remove('branch/d')
         stanza = regen(check_for_clean=True, include_file_revisions=True)
         file_rev_stanza = get_one_stanza(stanza, 'file-revisions')
-        self.assertEqual(['a', 'c', 'd'], file_rev_stanza.get_all('path'))
-        self.assertEqual(['r4', 'unversioned', 'removed'],
+        self.assertEqual(['', 'a', 'c', 'd'], file_rev_stanza.get_all('path'))
+        self.assertEqual(['r4', 'r4', 'unversioned', 'removed'],
                          file_rev_stanza.get_all('revision'))
 
     def test_python_version(self):
@@ -182,7 +184,8 @@
         self.build_tree(['branch/c'])
         tvi = regen(check_for_clean=True, include_file_revisions=True)
         self.assertEqual(False, tvi.version_info['clean'])
-        self.assertEqual(['a', 'b', 'c'], sorted(tvi.file_revisions.keys()))
+        self.assertEqual(['', 'a', 'b', 'c'], 
+                         sorted(tvi.file_revisions.keys()))
         self.assertEqual('r3', tvi.file_revisions['a'])
         self.assertEqual('r2', tvi.file_revisions['b'])
         self.assertEqual('unversioned', tvi.file_revisions['c'])
@@ -199,7 +202,8 @@
         wt.add('c')
         wt.rename_one('b', 'd')
         tvi = regen(check_for_clean=True, include_file_revisions=True)
-        self.assertEqual(['a', 'b', 'c', 'd'], sorted(tvi.file_revisions.keys()))
+        self.assertEqual(['', 'a', 'b', 'c', 'd'], 
+                          sorted(tvi.file_revisions.keys()))
         self.assertEqual('modified', tvi.file_revisions['a'])
         self.assertEqual('renamed to d', tvi.file_revisions['b'])
         self.assertEqual('new', tvi.file_revisions['c'])
@@ -209,7 +213,8 @@
         wt.remove(['c', 'd'])
         os.remove('branch/d')
         tvi = regen(check_for_clean=True, include_file_revisions=True)
-        self.assertEqual(['a', 'c', 'd'], sorted(tvi.file_revisions.keys()))
+        self.assertEqual(['', 'a', 'c', 'd'], 
+                          sorted(tvi.file_revisions.keys()))
         self.assertEqual('r4', tvi.file_revisions['a'])
         self.assertEqual('unversioned', tvi.file_revisions['c'])
         self.assertEqual('removed', tvi.file_revisions['d'])

=== modified file 'bzrlib/tests/test_versionedfile.py'
--- bzrlib/tests/test_versionedfile.py	2006-09-25 18:30:50 +0000
+++ bzrlib/tests/test_versionedfile.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # Authors:
 #   Johan Rydberg <jrydberg@gnu.org>

=== modified file 'bzrlib/tests/test_weave.py'
--- bzrlib/tests/test_weave.py	2006-09-20 22:32:33 +0000
+++ bzrlib/tests/test_weave.py	2006-10-11 23:08:27 +0000
@@ -1,6 +1,6 @@
 #! /usr/bin/python2.4
 
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_whitebox.py'
--- bzrlib/tests/test_whitebox.py	2006-10-05 22:42:09 +0000
+++ bzrlib/tests/test_whitebox.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/test_workingtree.py'
--- bzrlib/tests/test_workingtree.py	2006-09-15 02:03:15 +0000
+++ bzrlib/tests/test_workingtree.py	2006-09-22 04:52:17 +0000
@@ -173,9 +173,10 @@
         t = control.get_workingtree_transport(None)
         self.assertEqualDiff('Bazaar-NG Working Tree format 3',
                              t.get('format').read())
-        self.assertEqualDiff('<inventory format="5">\n'
-                             '</inventory>\n',
-                             t.get('inventory').read())
+        self.assertContainsRe(t.get('inventory').read(), 
+                              '<inventory file_id="[^"]*" format="5">\n'
+                              '</inventory>\n',
+                             )
         self.assertEqualDiff('### bzr hashcache v5\n',
                              t.get('stat-cache').read())
         self.assertFalse(t.has('inventory.basis'))

=== modified file 'bzrlib/tests/test_xml.py'
--- bzrlib/tests/test_xml.py	2006-08-16 20:55:23 +0000
+++ bzrlib/tests/test_xml.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/tree_implementations/__init__.py'
--- bzrlib/tests/tree_implementations/__init__.py	2006-09-05 11:52:44 +0000
+++ bzrlib/tests/tree_implementations/__init__.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -86,13 +86,15 @@
         :param empty_tree: A working tree with no content and no parents to
             modify.
         """
+        empty_tree.set_root_id('empty-root-id')
         return self._convert_tree(empty_tree, converter)
 
     def _make_abc_tree(self, tree):
         """setup an abc content tree."""
         files = ['a', 'b/', 'b/c']
-        self.build_tree(files, line_endings='binary',
+        self.build_tree(files, line_endings='binary', 
                         transport=tree.bzrdir.root_transport)
+        tree.set_root_id('root-id')
         tree.add(files, ['a-id', 'b-id', 'c-id'])
 
     def get_tree_no_parents_abc_content(self, tree, converter=None):

=== modified file 'bzrlib/tests/tree_implementations/test_test_trees.py'
--- bzrlib/tests/tree_implementations/test_test_trees.py	2006-08-05 22:33:36 +0000
+++ bzrlib/tests/tree_implementations/test_test_trees.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
 
 """Tests for the test trees used by the tree_implementations tests."""
 
-from bzrlib import inventory 
 from bzrlib.tests.tree_implementations import TestCaseWithTree
 
 
@@ -28,9 +27,9 @@
         self.assertEqual([], tree.get_parent_ids())
         self.assertEqual([], tree.conflicts())
         self.assertEqual([], list(tree.unknowns()))
-        self.assertEqual([inventory.ROOT_ID], list(iter(tree)))
+        self.assertEqual(['empty-root-id'], list(iter(tree)))
         self.assertEqual(
-            [('', inventory.ROOT_ID)],
+            [('', 'empty-root-id')],
             [(path, node.file_id) for path, node in tree.iter_entries_by_dir()])
 
     def test_abc_tree_no_parents(self):
@@ -41,10 +40,10 @@
         self.assertEqual([], list(tree.unknowns()))
         # __iter__ has no strongly defined order
         self.assertEqual(
-            set([inventory.ROOT_ID, 'a-id', 'b-id', 'c-id']),
+            set(['root-id', 'a-id', 'b-id', 'c-id']),
             set(iter(tree)))
         self.assertEqual(
-            [('', inventory.ROOT_ID), ('a', 'a-id'), ('b', 'b-id'), ('b/c', 'c-id')],
+            [('', 'root-id'), ('a', 'a-id'), ('b', 'b-id'), ('b/c', 'c-id')],
             [(path, node.file_id) for path, node in tree.iter_entries_by_dir()])
         self.assertEqualDiff('contents of a\n', tree.get_file_text('a-id'))
         self.assertFalse(tree.is_executable('c-id'))
@@ -57,10 +56,10 @@
         self.assertEqual([], list(tree.unknowns()))
         # __iter__ has no strongly defined order
         self.assertEqual(
-            set([inventory.ROOT_ID, 'a-id', 'b-id', 'c-id']),
+            set(['root-id', 'a-id', 'b-id', 'c-id']),
             set(iter(tree)))
         self.assertEqual(
-            [('', inventory.ROOT_ID), ('a', 'a-id'), ('b', 'b-id'), ('b/c', 'c-id')],
+            [('', 'root-id'), ('a', 'a-id'), ('b', 'b-id'), ('b/c', 'c-id')],
             [(path, node.file_id) for path, node in tree.iter_entries_by_dir()])
         self.assertEqualDiff('foobar\n', tree.get_file_text('a-id'))
         self.assertFalse(tree.is_executable('c-id'))
@@ -73,10 +72,10 @@
         self.assertEqual([], list(tree.unknowns()))
         # __iter__ has no strongly defined order
         self.assertEqual(
-            set([inventory.ROOT_ID, 'a-id', 'b-id', 'c-id']),
+            set(['root-id', 'a-id', 'b-id', 'c-id']),
             set(iter(tree)))
         self.assertEqual(
-            [('', inventory.ROOT_ID), ('a', 'a-id'), ('b', 'b-id'), ('b/c', 'c-id')],
+            [('', 'root-id'), ('a', 'a-id'), ('b', 'b-id'), ('b/c', 'c-id')],
             [(path, node.file_id) for path, node in tree.iter_entries_by_dir()])
         self.assertEqualDiff('contents of a\n', tree.get_file_text('a-id'))
         self.assertTrue(tree.is_executable('c-id'))
@@ -89,10 +88,10 @@
         self.assertEqual([], list(tree.unknowns()))
         # __iter__ has no strongly defined order
         self.assertEqual(
-            set([inventory.ROOT_ID, 'a-id', 'b-id', 'c-id']),
+            set(['root-id', 'a-id', 'b-id', 'c-id']),
             set(iter(tree)))
         self.assertEqual(
-            [('', inventory.ROOT_ID), ('b', 'b-id'), ('d', 'a-id'), ('b/c', 'c-id')],
+            [('', 'root-id'), ('b', 'b-id'), ('d', 'a-id'), ('b/c', 'c-id')],
             [(path, node.file_id) for path, node in tree.iter_entries_by_dir()])
         self.assertEqualDiff('contents of a\n', tree.get_file_text('a-id'))
         self.assertFalse(tree.is_executable('c-id'))
@@ -105,10 +104,10 @@
         self.assertEqual([], list(tree.unknowns()))
         # __iter__ has no strongly defined order
         self.assertEqual(
-            set([inventory.ROOT_ID, 'a-id', 'b-id', 'c-id']),
+            set(['root-id', 'a-id', 'b-id', 'c-id']),
             set(iter(tree)))
         self.assertEqual(
-            [('', inventory.ROOT_ID), ('b', 'b-id'), ('d', 'a-id'), ('b/c', 'c-id')],
+            [('', 'root-id'), ('b', 'b-id'), ('d', 'a-id'), ('b/c', 'c-id')],
             [(path, node.file_id) for path, node in tree.iter_entries_by_dir()])
         self.assertEqualDiff('bar\n', tree.get_file_text('a-id'))
         self.assertFalse(tree.is_executable('c-id'))
@@ -121,10 +120,10 @@
         self.assertEqual([], list(tree.unknowns()))
         # __iter__ has no strongly defined order
         self.assertEqual(
-            set([inventory.ROOT_ID, 'a-id', 'b-id', 'c-id']),
+            set(['root-id', 'a-id', 'b-id', 'c-id']),
             set(iter(tree)))
         self.assertEqual(
-            [('', inventory.ROOT_ID), ('a', 'a-id'), ('b', 'b-id'), ('e', 'c-id')],
+            [('', 'root-id'), ('a', 'a-id'), ('b', 'b-id'), ('e', 'c-id')],
             [(path, node.file_id) for path, node in tree.iter_entries_by_dir()])
         self.assertEqualDiff('contents of a\n', tree.get_file_text('a-id'))
         self.assertTrue(tree.is_executable('c-id'))

=== modified file 'bzrlib/tests/treeshape.py'
--- bzrlib/tests/treeshape.py	2006-07-28 16:05:23 +0000
+++ bzrlib/tests/treeshape.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/workingtree_implementations/__init__.py'
--- bzrlib/tests/workingtree_implementations/__init__.py	2006-09-07 23:31:28 +0000
+++ bzrlib/tests/workingtree_implementations/__init__.py	2006-10-16 04:50:19 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors: Robert Collins <robert.collins@canonical.com>
 # -*- coding: utf-8 -*-
 #
@@ -56,6 +56,7 @@
         'bzrlib.tests.workingtree_implementations.test_changes_from',
         'bzrlib.tests.workingtree_implementations.test_commit',
         'bzrlib.tests.workingtree_implementations.test_executable',
+        'bzrlib.tests.workingtree_implementations.test_flush',
         'bzrlib.tests.workingtree_implementations.test_get_parent_ids',
         'bzrlib.tests.workingtree_implementations.test_is_control_filename',
         'bzrlib.tests.workingtree_implementations.test_is_ignored',
@@ -65,6 +66,8 @@
         'bzrlib.tests.workingtree_implementations.test_pull',
         'bzrlib.tests.workingtree_implementations.test_put_file',
         'bzrlib.tests.workingtree_implementations.test_mkdir',
+        'bzrlib.tests.workingtree_implementations.test_read_working_inventory',
+        'bzrlib.tests.workingtree_implementations.test_set_root_id',
         'bzrlib.tests.workingtree_implementations.test_unversion',
         'bzrlib.tests.workingtree_implementations.test_workingtree',
         ]

=== modified file 'bzrlib/tests/workingtree_implementations/test_basis_inventory.py'
--- bzrlib/tests/workingtree_implementations/test_basis_inventory.py	2006-09-09 18:52:57 +0000
+++ bzrlib/tests/workingtree_implementations/test_basis_inventory.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005 by Canonical Ltd
+# Copyright (C) 2004, 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/workingtree_implementations/test_break_lock.py'
--- bzrlib/tests/workingtree_implementations/test_break_lock.py	2006-05-05 04:00:11 +0000
+++ bzrlib/tests/workingtree_implementations/test_break_lock.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# (C) 2006 Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors:  Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/workingtree_implementations/test_changes_from.py'
--- bzrlib/tests/workingtree_implementations/test_changes_from.py	2006-07-26 04:01:26 +0000
+++ bzrlib/tests/workingtree_implementations/test_changes_from.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Development Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/workingtree_implementations/test_executable.py'
--- bzrlib/tests/workingtree_implementations/test_executable.py	2006-09-05 08:14:23 +0000
+++ bzrlib/tests/workingtree_implementations/test_executable.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== added file 'bzrlib/tests/workingtree_implementations/test_flush.py'
--- bzrlib/tests/workingtree_implementations/test_flush.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/workingtree_implementations/test_flush.py	2006-10-16 04:50:19 +0000
@@ -0,0 +1,68 @@
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Tests for WorkingTree.flush."""
+
+from bzrlib import errors, inventory
+from bzrlib.tests.workingtree_implementations import TestCaseWithWorkingTree
+
+
+class TestFlush(TestCaseWithWorkingTree):
+
+    def test_flush_fresh_tree(self):
+        tree = self.make_branch_and_tree('t1')
+        tree.lock_write()
+        try:
+            tree.flush()
+        finally:
+            tree.unlock()
+
+    def test_flush_when_inventory_is_modified(self):
+        # when doing a flush the inventory should be written if needed.
+        # we test that by changing the inventory (using
+        # _set_inventory for now until add etc have lazy writes of
+        # the inventory on unlock).
+        tree = self.make_branch_and_tree('tree')
+        # prepare for a series of changes that will modify the 
+        # inventory
+        tree.lock_write()
+        try:
+            old_root = tree.get_root_id()
+            tree.set_root_id('new-root')
+            # to detect that the inventory is written by flush, we
+            # first check that it was not written yet.
+            reference_tree = tree.bzrdir.open_workingtree()
+            self.assertEqual(old_root, reference_tree.get_root_id())
+            # now flush the tree which should write the inventory.
+            tree.flush()
+            # and check it was written using another reference tree
+            reference_tree = tree.bzrdir.open_workingtree()
+            self.assertEqual('new-root', reference_tree.get_root_id())
+        finally:
+            tree.unlock()
+            
+    def test_flush_with_read_lock_fails(self):
+        """Flush cannot be used during a read lock."""
+        tree = self.make_branch_and_tree('t1')
+        tree.lock_read()
+        try:
+            self.assertRaises(errors.NotWriteLocked, tree.flush)
+        finally:
+            tree.unlock()
+            
+    def test_flush_with_no_lock_fails(self):
+        tree = self.make_branch_and_tree('t1')
+        self.assertRaises(errors.NotWriteLocked, tree.flush)

=== modified file 'bzrlib/tests/workingtree_implementations/test_get_parent_ids.py'
--- bzrlib/tests/workingtree_implementations/test_get_parent_ids.py	2006-09-05 09:49:40 +0000
+++ bzrlib/tests/workingtree_implementations/test_get_parent_ids.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# (C) 2006 Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors:  Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/workingtree_implementations/test_is_ignored.py'
--- bzrlib/tests/workingtree_implementations/test_is_ignored.py	2006-07-21 04:02:14 +0000
+++ bzrlib/tests/workingtree_implementations/test_is_ignored.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# (C) 2006 Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors:  Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/workingtree_implementations/test_locking.py'
--- bzrlib/tests/workingtree_implementations/test_locking.py	2006-09-27 22:12:53 +0000
+++ bzrlib/tests/workingtree_implementations/test_locking.py	2006-10-13 07:39:25 +0000
@@ -100,6 +100,52 @@
         self.assertTrue(wt.branch.is_locked())
         wt.branch.unlock()
         
+    def _test_unlock_with_lock_method(self, methodname):
+        """Create a tree and then test its unlocking behaviour.
+
+        :param methodname: The lock method to use to establish locks.
+        """
+        # when unlocking the last lock count from tree_write_lock,
+        # the tree should do a flush().
+        # we test that by changing the inventory using set_root_id
+        tree = self.make_branch_and_tree('tree')
+        # prepare for a series of changes that will modify the 
+        # inventory
+        getattr(tree, methodname)()
+        # note that we dont have a try:finally here because of two reasons:
+        # firstly there will only be errors reported if the test fails, and 
+        # when it fails thats ok as long as the test suite cleanup still works,
+        # which it will as the lock objects are released (thats where the 
+        # warning comes from.  Secondly, it is hard in this test to be 
+        # sure that we've got the right interactions between try:finally
+        # and the lock/unlocks we are doing.
+        getattr(tree, methodname)()
+        # this should really do something within the public api
+        # e.g. mkdir('foo') but all the mutating methods at the
+        # moment trigger inventory writes and thus will not 
+        # let us trigger a read-when-dirty situation.
+        old_root = tree.get_root_id()
+        tree.set_root_id('new-root')
+        # to detect that the inventory is written by unlock, we
+        # first check that it was not written yet.
+        reference_tree = tree.bzrdir.open_workingtree()
+        self.assertEqual(old_root, reference_tree.get_root_id())
+        # now unlock the second held lock, which should do nothing.
+        tree.unlock()
+        reference_tree = tree.bzrdir.open_workingtree()
+        self.assertEqual(old_root, reference_tree.get_root_id())
+        # unlocking the first lock we took will now flush.
+        tree.unlock()
+        # and check it was written using another reference tree
+        reference_tree = tree.bzrdir.open_workingtree()
+        self.assertEqual('new-root', reference_tree.get_root_id())
+
+    def test_unlock_from_tree_write_lock_flushes(self):
+        self._test_unlock_with_lock_method("lock_tree_write")
+        
+    def test_unlock_from_write_lock_flushes(self):
+        self._test_unlock_with_lock_method("lock_write")
+        
     def test_unlock_branch_failures(self):
         """If the branch unlock fails the tree must still unlock."""
         # The public interface for WorkingTree requires a branch, but

=== modified file 'bzrlib/tests/workingtree_implementations/test_mkdir.py'
--- bzrlib/tests/workingtree_implementations/test_mkdir.py	2006-09-07 23:13:08 +0000
+++ bzrlib/tests/workingtree_implementations/test_mkdir.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# (C) 2006 Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors:  Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/workingtree_implementations/test_parents.py'
--- bzrlib/tests/workingtree_implementations/test_parents.py	2006-09-08 00:19:48 +0000
+++ bzrlib/tests/workingtree_implementations/test_parents.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/workingtree_implementations/test_put_file.py'
--- bzrlib/tests/workingtree_implementations/test_put_file.py	2006-09-07 23:13:08 +0000
+++ bzrlib/tests/workingtree_implementations/test_put_file.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# (C) 2006 Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 # Authors:  Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== added file 'bzrlib/tests/workingtree_implementations/test_read_working_inventory.py'
--- bzrlib/tests/workingtree_implementations/test_read_working_inventory.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/workingtree_implementations/test_read_working_inventory.py	2006-10-16 04:50:19 +0000
@@ -0,0 +1,40 @@
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Tests for WorkingTree.read_working_inventory."""
+
+from bzrlib import errors, inventory
+from bzrlib.tests.workingtree_implementations import TestCaseWithWorkingTree
+
+
+class TestReadWorkingInventory(TestCaseWithWorkingTree):
+
+    def test_trivial_read(self):
+        tree = self.make_branch_and_tree('t1')
+        self.assertIsInstance(tree.read_working_inventory(), inventory.Inventory)
+
+    def test_read_after_inventory_modification(self):
+        tree = self.make_branch_and_tree('tree')
+        # prepare for a series of changes that will modify the 
+        # inventory
+        tree.lock_write()
+        try:
+            tree.set_root_id('new-root')
+            # having dirtied the inventory, we can now expect an 
+            # InventoryModified exception when doing a read_working_inventory()
+            self.assertRaises(errors.InventoryModified, tree.read_working_inventory)
+        finally:
+            tree.unlock()

=== added file 'bzrlib/tests/workingtree_implementations/test_set_root_id.py'
--- bzrlib/tests/workingtree_implementations/test_set_root_id.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/workingtree_implementations/test_set_root_id.py	2006-10-16 04:50:19 +0000
@@ -0,0 +1,57 @@
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Tests for WorkingTree.set_root_id"""
+
+from bzrlib import inventory
+from bzrlib.symbol_versioning import zero_twelve
+from bzrlib.tests.workingtree_implementations import TestCaseWithWorkingTree
+
+
+class TestSetRootId(TestCaseWithWorkingTree):
+
+    def test_set_None(self):
+        # setting the root_id to None is equivalent to setting it
+        # to inventory.ROOT_ID
+        tree = self.make_branch_and_tree('a-tree')
+        self.callDeprecated([
+            'WorkingTree.set_root_id with fileid=None was deprecated in version'
+            ' 0.12.'],
+            tree.set_root_id, None)
+        self.assertEqual(inventory.ROOT_ID, tree.get_root_id())
+
+    def test_set_and_read_unicode(self):
+        tree = self.make_branch_and_tree('a-tree')
+        # setting the root id allows it to be read via get_root_id.
+        tree.lock_write()
+        try:
+            old_id = tree.get_root_id()
+            tree.set_root_id(u'\xe5n id')
+            self.assertEqual(u'\xe5n id', tree.get_root_id())
+            # set root id should not have triggered a flush of the tree,
+            # so check a new tree sees the old state.
+            reference_tree = tree.bzrdir.open_workingtree()
+            self.assertEqual(old_id, reference_tree.get_root_id())
+        finally:
+            tree.unlock()
+        # having unlocked the tree, the value should have been 
+        # preserved into the next lock, which is an implicit read
+        # lock around the get_root_id call.
+        self.assertEqual(u'\xe5n id', tree.get_root_id())
+        # and if we get a new working tree instance, then the value
+        # should still be retained
+        tree = tree.bzrdir.open_workingtree()
+        self.assertEqual(u'\xe5n id', tree.get_root_id())

=== modified file 'bzrlib/tests/workingtree_implementations/test_unversion.py'
--- bzrlib/tests/workingtree_implementations/test_unversion.py	2006-09-07 08:13:22 +0000
+++ bzrlib/tests/workingtree_implementations/test_unversion.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tests/workingtree_implementations/test_workingtree.py'
--- bzrlib/tests/workingtree_implementations/test_workingtree.py	2006-09-08 00:19:48 +0000
+++ bzrlib/tests/workingtree_implementations/test_workingtree.py	2006-09-10 19:04:48 +0000
@@ -413,6 +413,28 @@
         self.failUnlessExists('checkout/file')
         self.assertEqual(['A'], old_tree.get_parent_ids())
 
+    def test_update_sets_root_id(self):
+        """Ensure tree root is set properly by update.
+        
+        Since empty trees don't have root_ids, but workingtrees do,
+        an update of a checkout of revision 0 to a new revision,  should set
+        the root id.
+        """
+        wt = self.make_branch_and_tree('tree')
+        main_branch = wt.branch
+        # create an out of date working tree by making a checkout in this
+        # current format
+        self.build_tree(['checkout/', 'tree/file'])
+        checkout = main_branch.create_checkout('checkout')
+        # now commit to 'tree'
+        wt.add('file')
+        wt.commit('A', rev_id='A')
+        # and update checkout 
+        self.assertEqual(0, checkout.update())
+        self.failUnlessExists('checkout/file')
+        self.assertEqual(wt.get_root_id(), checkout.get_root_id())
+        self.assertNotEqual(None, wt.get_root_id())
+
     def test_update_returns_conflict_count(self):
         # working tree formats from the meta-dir format and newer support
         # setting the last revision on a tree independently of that on the 

=== modified file 'bzrlib/textfile.py'
--- bzrlib/textfile.py	2006-06-30 21:38:52 +0000
+++ bzrlib/textfile.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/textinv.py'
--- bzrlib/textinv.py	2006-08-07 23:14:45 +0000
+++ bzrlib/textinv.py	2006-10-16 01:50:48 +0000
@@ -1,4 +1,4 @@
-# (C) 2005 Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -52,9 +52,10 @@
 def write_text_inventory(inv, outf):
     """Write out inv in a simple trad-unix text format."""
     outf.write(START_MARK)
-    entries = inv.iter_entries()
-    entries.next()
-    for path, ie in entries:
+    for path, ie in inv.iter_entries():
+        if inv.is_root(ie.file_id):
+            continue
+        
         outf.write(ie.file_id + ' ')
         outf.write(escape(ie.name) + ' ')
         outf.write(ie.kind + ' ')

=== modified file 'bzrlib/textui.py'
--- bzrlib/textui.py	2006-07-30 06:52:39 +0000
+++ bzrlib/textui.py	2006-10-11 23:08:27 +0000
@@ -1,6 +1,6 @@
 # Bazaar -- distributed version control
 #
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/trace.py'
--- bzrlib/trace.py	2006-10-06 07:14:31 +0000
+++ bzrlib/trace.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/transactions.py'
--- bzrlib/transactions.py	2006-08-30 13:54:51 +0000
+++ bzrlib/transactions.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2006-09-27 19:14:52 +0000
+++ bzrlib/transform.py	2006-09-28 01:53:23 +0000
@@ -21,7 +21,7 @@
 from bzrlib import bzrdir, errors
 from bzrlib.errors import (DuplicateKey, MalformedTransform, NoSuchFile,
                            ReusingTransform, NotVersionedError, CantMoveRoot,
-                           ExistingLimbo, ImmortalLimbo)
+                           ExistingLimbo, ImmortalLimbo, NoFinalPath)
 from bzrlib.inventory import InventoryEntry
 from bzrlib.osutils import (file_kind, supports_executable, pathjoin, lexists,
                             delete_any)
@@ -457,7 +457,10 @@
         try:
             return self._new_name[trans_id]
         except KeyError:
-            return os.path.basename(self._tree_id_paths[trans_id])
+            try:
+                return os.path.basename(self._tree_id_paths[trans_id])
+            except KeyError:
+                raise NoFinalPath(trans_id, self)
 
     def by_parent(self):
         """Return a map of parent: children for known parents.
@@ -570,7 +573,10 @@
             parent_id = trans_id
             while parent_id is not ROOT_PARENT:
                 seen.add(parent_id)
-                parent_id = self.final_parent(parent_id)
+                try:
+                    parent_id = self.final_parent(parent_id)
+                except KeyError:
+                    break
                 if parent_id == trans_id:
                     conflicts.append(('parent loop', trans_id))
                 if parent_id in seen:
@@ -958,6 +964,8 @@
     file_trans_id = {}
     top_pb = bzrlib.ui.ui_factory.nested_progress_bar()
     pp = ProgressPhase("Build phase", 2, top_pb)
+    if tree.inventory.root is not None:
+        wt.set_root_id(tree.inventory.root.file_id)
     tt = TreeTransform(wt)
     divert = set()
     try:
@@ -1232,6 +1240,9 @@
         basis_tree = None
         try:
             for id_num, file_id in enumerate(wt_interesting):
+                if (working_tree.inventory.is_root(file_id) and 
+                    len(target_tree.inventory) == 0):
+                    continue
                 child_pb.update("New file check", id_num+1, 
                                 len(sorted_interesting))
                 if file_id not in target_tree:

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2006-10-13 06:41:04 +0000
+++ bzrlib/transport/__init__.py	2006-10-13 08:56:23 +0000
@@ -330,6 +330,8 @@
                 => '/home/sarah/project/foo'
             t._combine_paths('/home/sarah', '../../etc')
                 => '/etc'
+            t._combine_paths('/home/sarah', '/etc')
+                => '/etc'
 
         :param base_path: urlencoded path for the transport root; typically a 
              URL but need not contain scheme/host/etc.
@@ -361,6 +363,8 @@
             elif p != '':
                 base_parts.append(p)
         path = '/'.join(base_parts)
+        if not path.startswith('/'):
+            path = '/' + path
         return path
 
     def relpath(self, abspath):

=== modified file 'bzrlib/transport/http/_pycurl_errors.py'
--- bzrlib/transport/http/_pycurl_errors.py	2006-07-14 01:46:36 +0000
+++ bzrlib/transport/http/_pycurl_errors.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/transport/http/response.py'
--- bzrlib/transport/http/response.py	2006-10-13 06:36:44 +0000
+++ bzrlib/transport/http/response.py	2006-10-16 01:50:48 +0000
@@ -1,5 +1,4 @@
-# Copyright (C) 2006 Michael Ellerman
-#           modified by John Arbash Meinel (Canonical Ltd)
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2006-09-21 22:02:58 +0000
+++ bzrlib/tree.py	2006-09-28 22:56:04 +0000
@@ -218,7 +218,7 @@
 class EmptyTree(Tree):
 
     def __init__(self):
-        self._inventory = Inventory()
+        self._inventory = Inventory(root_id=None)
         warn('EmptyTree is deprecated as of bzr 0.9 please use '
             'repository.revision_tree instead.',
             DeprecationWarning, stacklevel=2)
@@ -236,7 +236,7 @@
         assert self._inventory[file_id].kind == "directory"
         return "directory"
 
-    def list_files(self):
+    def list_files(self, include_root=False):
         return iter([])
     
     def __contains__(self, file_id):

=== modified file 'bzrlib/treebuilder.py'
--- bzrlib/treebuilder.py	2006-09-15 02:03:15 +0000
+++ bzrlib/treebuilder.py	2006-09-22 04:52:17 +0000
@@ -31,6 +31,7 @@
     def __init__(self):
         """Construct a TreeBuilder."""
         self._tree = None
+        self._root_done = False
 
     def build(self, recipe):
         """Build recipe into the current tree.
@@ -40,6 +41,9 @@
             '/' then a directory is added, otherwise a regular file is added.
         """
         self._ensure_building()
+        if not self._root_done:
+            self._tree.add('', 'root-id', 'directory')
+            self._root_done = True
         for name in recipe:
             assert isinstance(name, basestring)
             if name[-1] == '/':
@@ -73,4 +77,3 @@
             raise errors.AlreadyBuilding
         self._tree = tree
         self._tree.lock_tree_write()
-

=== modified file 'bzrlib/tsort.py'
--- bzrlib/tsort.py	2006-03-28 14:29:13 +0000
+++ bzrlib/tsort.py	2006-10-16 10:03:21 +0000
@@ -1,4 +1,4 @@
-# (C) 2005, 2006 Canonical Limited.
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -159,7 +159,7 @@
         return node_name
 
 
-def merge_sort(graph, branch_tip, mainline_revisions=None):
+def merge_sort(graph, branch_tip, mainline_revisions=None, generate_revno=False):
     """Topological sort a graph which groups merges.
 
     :param graph: sequence of pairs of node->parents_list.
@@ -174,18 +174,20 @@
                                old revision listed in the mainline revisions
                                list.
                                The order for this parameter is oldest-first.
-
-    The result is a list of node names, such that all parents come before
-    their children.
-
+    :param generate_revno: Optional parameter controlling the generation of
+        revision number sequences in the output. See the output description of
+        the MergeSorter docstring for details.
+    :result: See the MergeSorter docstring for details.
     node identifiers can be any hashable object, and are typically strings.
     """
-    return MergeSorter(graph, branch_tip, mainline_revisions).sorted()
+    return MergeSorter(graph, branch_tip, mainline_revisions,
+        generate_revno).sorted()
 
 
 class MergeSorter(object):
 
-    def __init__(self, graph, branch_tip, mainline_revisions=None):
+    def __init__(self, graph, branch_tip, mainline_revisions=None,
+        generate_revno=False):
         """Merge-aware topological sorting of a graph.
     
         :param graph: sequence of pairs of node_name->parent_names_list.
@@ -204,6 +206,29 @@
                                old revision listed in the mainline revisions
                                list.
                                The order for this parameter is oldest-first.
+        :param generate_revno: Optional parameter controlling the generation of
+            revision number sequences in the output. See the output description
+            for more details.
+
+        The result is a list sorted so that all parents come before
+        their children. Each element of the list is a tuple containing:
+        (sequence_number, node_name, merge_depth, end_of_merge)
+         * sequence_number: The sequence of this row in the output. Useful for 
+           GUIs.
+         * node_name: The node name: opaque text to the merge routine.
+         * merge_depth: How many levels of merging deep this node has been
+           found.
+         * revno_sequence: When requested this field provides a sequence of
+             revision numbers for all revisions. The format is:
+             REVNO[[.BRANCHREVNO.REVNO] ...]. BRANCHREVNO is the number of the
+             branch that the revno is on. From left to right the REVNO numbers
+             are the sequence numbers within that branch of the revision.
+             For instance, the graph {A:[], B:['A'], C:['A', 'B']} will get
+             the following revno_sequences assigned: A:(1,), B:(1,1,1), C:(2,).
+             This should be read as 'A is the first commit in the trunk',
+             'B is the first commit on the first branch made from A', 'C is the
+             second commit in the trunk'.
+         * end_of_merge: When True the next node is part of a different merge.
 
         
         node identifiers can be any hashable object, and are typically strings.
@@ -285,6 +310,7 @@
              XXXX revisit when awake. ddaa asks about the relevance of each one
              - maybe more than one parent is relevant
         """
+        self._generate_revno = generate_revno
         # a dict of the graph.
         self._graph = dict(graph)
         # if there is an explicit mainline, alter the graph to match. This is
@@ -315,6 +341,17 @@
         # which requires the parents to be accessible: its easier for now
         # to just keep the original graph around.
         self._original_graph = dict(self._graph.items())
+        # we need to know the revision numbers of revisions to determine
+        # the revision numbers of their descendants
+        # this is a graph from node to [revno_tuple, sequence_number]
+        # where sequence is the number of branches made from the node,
+        # and revno_tuple is the tuple that was assigned to the node.
+        # we dont know revnos to start with, so we start it seeded with
+        # [None, 0]
+        self._revnos = dict((revision, [None, 0]) for revision in self._graph)
+        # the global implicit root node has revno 0, but we need to know
+        # the sequence number for it too:
+        self._root_sequence = 0
         
         # this is a stack storing the depth first search into the graph.
         self._node_name_stack = []
@@ -324,6 +361,9 @@
         # stack stores the parents we have not yet checked for the node at the 
         # matching depth in _node_name_stack
         self._pending_parents_stack = []
+        # When we first look at a node we assign it a seqence number from its
+        # leftmost parent.
+        self._assigned_sequence_stack = []
         # this is a set of the nodes who have been completely analysed for fast
         # membership checking
         self._completed_node_names = set()
@@ -343,7 +383,8 @@
         # This records for each node when we have processed its left most 
         # unmerged subtree. After this subtree is scheduled, all other subtrees
         # have their merge depth increased by one from this nodes merge depth.
-        self._left_subtree_done_stack = []
+        # it contains tuples - name, merge_depth
+        self._left_subtree_pushed_stack = []
 
         # seed the search with the tip of the branch
         if branch_tip is not None:
@@ -374,7 +415,7 @@
                 self._pop_node()
             else:
                 while self._pending_parents_stack[-1]:
-                    if not self._left_subtree_done_stack[-1]:
+                    if not self._left_subtree_pushed_stack[-1]:
                         # recurse depth first into the primary parent
                         next_node_name = self._pending_parents_stack[-1].pop(0)
                     else:
@@ -402,11 +443,12 @@
                         # this indicates a cycle.
                         raise errors.GraphCycleError(self._node_name_stack)
                     next_merge_depth = 0
-                    if self._left_subtree_done_stack[-1]:
+                    if self._left_subtree_pushed_stack[-1]:
+                        # a new child branch from name_stack[-1]
                         next_merge_depth = 1
                     else:
                         next_merge_depth = 0
-                        self._left_subtree_done_stack[-1] = True
+                        self._left_subtree_pushed_stack[-1] = True
                     next_merge_depth = (
                         self._node_merge_depth_stack[-1] + next_merge_depth)
                     self._push_node(
@@ -419,10 +461,11 @@
         # We have scheduled the graph. Now deliver the ordered output:
         sequence_number = 0
         while self._scheduled_nodes:
-            node_name, merge_depth = self._scheduled_nodes.pop()
+            node_name, merge_depth, revno = self._scheduled_nodes.pop()
             if node_name == self._stop_revision:
                 return
             if not len(self._scheduled_nodes):
+                # last revision is the end of a merge
                 end_of_merge = True
             elif self._scheduled_nodes[-1][1] < merge_depth:
                 # the next node is to our left
@@ -434,7 +477,10 @@
                 end_of_merge = True
             else:
                 end_of_merge = False
-            yield (sequence_number, node_name, merge_depth, end_of_merge)
+            if self._generate_revno:
+                yield (sequence_number, node_name, merge_depth, revno, end_of_merge)
+            else:
+                yield (sequence_number, node_name, merge_depth, end_of_merge)
             sequence_number += 1
 
     def _push_node(self, node_name, merge_depth, parents):
@@ -445,8 +491,20 @@
         """
         self._node_name_stack.append(node_name)
         self._node_merge_depth_stack.append(merge_depth)
-        self._left_subtree_done_stack.append(False)
+        self._left_subtree_pushed_stack.append(False)
         self._pending_parents_stack.append(list(parents))
+        # as we push it, assign it a sequence number against its parent:
+        parents = self._original_graph[node_name]
+        if parents:
+            # node has parents, assign from the left most parent.
+            parent_revno = self._revnos[parents[0]]
+            sequence = parent_revno[1]
+            parent_revno[1] += 1
+        else:
+            # no parents, use the root sequence
+            sequence = self._root_sequence
+            self._root_sequence +=1
+        self._assigned_sequence_stack.append(sequence)
 
     def _pop_node(self):
         """Pop the top node off the stack 
@@ -457,9 +515,31 @@
         # pop off the local variables
         node_name = self._node_name_stack.pop()
         merge_depth = self._node_merge_depth_stack.pop()
-        self._left_subtree_done_stack.pop()
+        sequence = self._assigned_sequence_stack.pop()
+        # remove this node from the pending lists:
+        self._left_subtree_pushed_stack.pop()
         self._pending_parents_stack.pop()
 
+        parents = self._original_graph[node_name]
+        if parents:
+            # node has parents, assign from the left most parent.
+            parent_revno = self._revnos[parents[0]]
+            if sequence:
+                # not the first child, make a new branch
+                revno = parent_revno[0] + (sequence, 1)
+            else:
+                # increment the sequence number within the branch
+                revno = parent_revno[0][:-1] + (parent_revno[0][-1] + 1,)
+        else:
+            # no parents, use the root sequence
+            if sequence:
+                # make a parallel import revision number
+                revno = (0, sequence, 1)
+            else:
+                revno = (1,)
+
+        # store the revno for this node for future reference
+        self._revnos[node_name][0] = revno
         self._completed_node_names.add(node_name)
-        self._scheduled_nodes.append((node_name, merge_depth))
+        self._scheduled_nodes.append((node_name, merge_depth, self._revnos[node_name][0]))
         return node_name

=== modified file 'bzrlib/tuned_gzip.py'
--- bzrlib/tuned_gzip.py	2006-08-17 13:25:05 +0000
+++ bzrlib/tuned_gzip.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 # Written by Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/urlutils.py'
--- bzrlib/urlutils.py	2006-10-06 05:53:44 +0000
+++ bzrlib/urlutils.py	2006-10-16 01:25:46 +0000
@@ -1,6 +1,6 @@
 # Bazaar -- distributed version control
 #
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/version.py'
--- bzrlib/version.py	2006-08-23 03:41:54 +0000
+++ bzrlib/version.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005, 2006 by Canonical Ltd
+# Copyright (C) 2004, 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/version_info_formats/__init__.py'
--- bzrlib/version_info_formats/__init__.py	2006-09-21 16:33:39 +0000
+++ bzrlib/version_info_formats/__init__.py	2006-09-29 00:04:13 +0000
@@ -85,13 +85,14 @@
             basis_tree = self._branch.basis_tree()
 
         # Build up the list from the basis inventory
-        for info in basis_tree.list_files():
+        for info in basis_tree.list_files(include_root=True):
             self._file_revisions[info[0]] = info[-1].revision
 
         if not self._check or self._working_tree is None:
             return
 
-        delta = self._working_tree.changes_from(basis_tree)
+        delta = self._working_tree.changes_from(basis_tree, 
+                                                include_root=True)
 
         # Using a 2-pass algorithm for renames. This is because you might have
         # renamed something out of the way, and then created a new file

=== modified file 'bzrlib/versionedfile.py'
--- bzrlib/versionedfile.py	2006-10-06 05:53:44 +0000
+++ bzrlib/versionedfile.py	2006-10-16 01:25:46 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 by Canonical Ltd
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # Authors:
 #   Johan Rydberg <jrydberg@gnu.org>

=== modified file 'bzrlib/weave_commands.py'
--- bzrlib/weave_commands.py	2006-07-28 16:05:23 +0000
+++ bzrlib/weave_commands.py	2006-10-11 23:08:27 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Canonical Ltd
+# Copyright (C) 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'bzrlib/win32console.py'
--- bzrlib/win32console.py	2006-06-20 03:57:11 +0000
+++ bzrlib/win32console.py	2006-10-05 05:37:25 +0000
@@ -1,3 +1,19 @@
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 
 """
 Set of functions to work with console on Windows.

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2006-10-06 06:27:06 +0000
+++ bzrlib/workingtree.py	2006-10-16 01:13:59 +0000
@@ -58,9 +58,9 @@
     ignores,
     merge,
     osutils,
-    urlutils,
     textui,
     transform,
+    urlutils,
     xml5,
     xml6,
     )
@@ -69,6 +69,7 @@
 import bzrlib.ui
 """)
 
+from bzrlib import symbol_versioning
 from bzrlib.decorators import needs_read_lock, needs_write_lock
 from bzrlib.errors import (BzrCheckError,
                            BzrError,
@@ -80,7 +81,7 @@
                            MergeModifiedFormatError,
                            UnsupportedOperation,
                            )
-from bzrlib.inventory import InventoryEntry, Inventory
+from bzrlib.inventory import InventoryEntry, Inventory, ROOT_ID
 from bzrlib.lockable_files import LockableFiles, TransportLock
 from bzrlib.lockdir import LockDir
 import bzrlib.mutabletree
@@ -164,7 +165,7 @@
 
 def gen_root_id():
     """Return a new tree-root file id."""
-    return gen_file_id('TREE_ROOT')
+    return gen_file_id('tree_root')
 
 
 class TreeEntry(object):
@@ -259,7 +260,7 @@
             self.basedir = wt.basedir
             self._control_files = wt._control_files
             self._hashcache = wt._hashcache
-            self._set_inventory(wt._inventory)
+            self._set_inventory(wt._inventory, dirty=False)
             self._format = wt._format
             self.bzrdir = wt.bzrdir
         from bzrlib.hashcache import HashCache
@@ -307,9 +308,14 @@
             hc.write()
 
         if _inventory is None:
-            self._set_inventory(self.read_working_inventory())
+            self._inventory_is_modified = False
+            self.read_working_inventory()
         else:
-            self._set_inventory(_inventory)
+            # the caller of __init__ has provided an inventory,
+            # we assume they know what they are doing - as its only
+            # the Format factory and creation methods that are
+            # permitted to do this.
+            self._set_inventory(_inventory, dirty=False)
 
     branch = property(
         fget=lambda self: self._branch,
@@ -330,9 +336,19 @@
         self._control_files.break_lock()
         self.branch.break_lock()
 
-    def _set_inventory(self, inv):
+    def _set_inventory(self, inv, dirty):
+        """Set the internal cached inventory.
+
+        :param inv: The inventory to set.
+        :param dirty: A boolean indicating whether the inventory is the same
+            logical inventory as whats on disk. If True the inventory is not
+            the same and should be written to disk or data will be lost, if
+            False then the inventory is the same as that on disk and any
+            serialisation would be unneeded overhead.
+        """
         assert inv.root is not None
         self._inventory = inv
+        self._inventory_is_modified = dirty
 
     @staticmethod
     def open(path=None, _unsupported=False):
@@ -503,10 +519,10 @@
                 parents.append(l.rstrip('\n'))
         return parents
 
+    @needs_read_lock
     def get_root_id(self):
         """Return the id of this trees root"""
-        inv = self.read_working_inventory()
-        return inv.root.file_id
+        return self._inventory.root.file_id
         
     def _get_store_filename(self, file_id):
         ## XXX: badly named; this is not in the store at all
@@ -538,6 +554,7 @@
     @needs_read_lock
     def copy_content_into(self, tree, revision_id=None):
         """Copy the current content and user files of this tree into tree."""
+        tree.set_root_id(self.get_root_id())
         if revision_id is None:
             merge.transform_tree(tree, self)
         else:
@@ -849,6 +866,17 @@
         else:
             return '?'
 
+    def flush(self):
+        """Write the in memory inventory to disk."""
+        # TODO: Maybe this should only write on dirty ?
+        if self._control_files._lock_mode != 'w':
+            raise errors.NotWriteLocked(self)
+        sio = StringIO()
+        xml5.serializer_v5.write_inventory(self._inventory, sio)
+        sio.seek(0)
+        self._control_files.put('inventory', sio)
+        self._inventory_is_modified = False
+
     def list_files(self, include_root=False):
         """Recursively list all files as (path, class, kind, id, entry).
 
@@ -1010,7 +1038,10 @@
         # create a file in this interval and then the rename might be
         # left half-done.  But we should have caught most problems.
         orig_inv = deepcopy(self.inventory)
+        original_modified = self._inventory_is_modified
         try:
+            if len(from_paths):
+                self._inventory_is_modified = True
             for f in from_paths:
                 name_tail = splitpath(f)[-1]
                 dest_path = pathjoin(to_name, name_tail)
@@ -1024,7 +1055,7 @@
                             ["rename rolled back"])
         except:
             # restore the inventory on error
-            self._set_inventory(orig_inv)
+            self._set_inventory(orig_inv, dirty=original_modified)
             raise
         self._write_inventory(inv)
         return result
@@ -1158,6 +1189,9 @@
                                 basis_tree,
                                 this_tree=self,
                                 pb=pb)
+                    if (basis_tree.inventory.root is None and
+                        new_basis_tree.inventory.root is not None):
+                        self.set_root_id(new_basis_tree.inventory.root.file_id)
                 finally:
                     pb.finished()
                 # TODO - dedup parents list with things merged by pull ?
@@ -1471,12 +1505,20 @@
         
     @needs_read_lock
     def read_working_inventory(self):
-        """Read the working inventory."""
+        """Read the working inventory.
+        
+        :raises errors.InventoryModified: read_working_inventory will fail
+            when the current in memory inventory has been modified.
+        """
+        # conceptually this should be an implementation detail of the tree. 
+        # XXX: Deprecate this.
         # ElementTree does its own conversion from UTF-8, so open in
         # binary.
+        if self._inventory_is_modified:
+            raise errors.InventoryModified(self)
         result = xml5.serializer_v5.read_inventory(
             self._control_files.get('inventory'))
-        self._set_inventory(result)
+        self._set_inventory(result, dirty=False)
         return result
 
     @needs_tree_write_lock
@@ -1562,16 +1604,31 @@
     @needs_tree_write_lock
     def set_root_id(self, file_id):
         """Set the root id for this tree."""
-        inv = self.read_working_inventory()
+        # for compatability 
+        if file_id is None:
+            symbol_versioning.warn(symbol_versioning.zero_twelve
+                % 'WorkingTree.set_root_id with fileid=None',
+                DeprecationWarning,
+                stacklevel=3)
+            file_id = ROOT_ID
+        inv = self._inventory
         orig_root_id = inv.root.file_id
+        # TODO: it might be nice to exit early if there was nothing
+        # to do, saving us from trigger a sync on unlock.
+        self._inventory_is_modified = True
+        # we preserve the root inventory entry object, but
+        # unlinkit from the byid index
         del inv._byid[inv.root.file_id]
         inv.root.file_id = file_id
+        # and link it into the index with the new changed id.
         inv._byid[inv.root.file_id] = inv.root
+        # and finally update all children to reference the new id.
+        # XXX: this should be safe to just look at the root.children
+        # list, not the WHOLE INVENTORY.
         for fid in inv:
             entry = inv[fid]
             if entry.parent_id == orig_root_id:
                 entry.parent_id = inv.root.file_id
-        self._write_inventory(inv)
 
     def unlock(self):
         """See Branch.unlock.
@@ -1588,23 +1645,30 @@
     def update(self):
         """Update a working tree along its branch.
 
-        This will update the branch if its bound too, which means we have multiple trees involved:
-        The new basis tree of the master.
-        The old basis tree of the branch.
-        The old basis tree of the working tree.
-        The current working tree state.
-        pathologically all three may be different, and non ancestors of each other.
-        Conceptually we want to:
-        Preserve the wt.basis->wt.state changes
-        Transform the wt.basis to the new master basis.
-        Apply a merge of the old branch basis to get any 'local' changes from it into the tree.
-        Restore the wt.basis->wt.state changes.
+        This will update the branch if its bound too, which means we have
+        multiple trees involved:
+
+        - The new basis tree of the master.
+        - The old basis tree of the branch.
+        - The old basis tree of the working tree.
+        - The current working tree state.
+
+        Pathologically, all three may be different, and non-ancestors of each
+        other.  Conceptually we want to:
+
+        - Preserve the wt.basis->wt.state changes
+        - Transform the wt.basis to the new master basis.
+        - Apply a merge of the old branch basis to get any 'local' changes from
+          it into the tree.
+        - Restore the wt.basis->wt.state changes.
 
         There isn't a single operation at the moment to do that, so we:
-        Merge current state -> basis tree of the master w.r.t. the old tree basis.
-        Do a 'normal' merge of the old branch basis if it is relevant.
+        - Merge current state -> basis tree of the master w.r.t. the old tree
+          basis.
+        - Do a 'normal' merge of the old branch basis if it is relevant.
         """
         old_tip = self.branch.update()
+
         # here if old_tip is not None, it is the old tip of the branch before
         # it was updated from the master branch. This should become a pending
         # merge in the working tree to preserve the user existing work.  we
@@ -1624,6 +1688,8 @@
             # merge tree state up to new branch tip.
             basis = self.basis_tree()
             to_tree = self.branch.basis_tree()
+            if basis.inventory.root is None:
+                self.set_root_id(to_tree.inventory.root.file_id)
             result += merge.merge_inner(
                                   self.branch,
                                   to_tree,
@@ -1676,12 +1742,8 @@
     @needs_tree_write_lock
     def _write_inventory(self, inv):
         """Write inventory as the current inventory."""
-        sio = StringIO()
-        xml5.serializer_v5.write_inventory(inv, sio)
-        sio.seek(0)
-        self._control_files.put('inventory', sio)
-        self._set_inventory(inv)
-        mutter('wrote working inventory')
+        self._set_inventory(inv, dirty=True)
+        self.flush()
 
     def set_conflicts(self, arg):
         raise UnsupportedOperation(self.set_conflicts, self)
@@ -1739,8 +1801,12 @@
 
     def unlock(self):
         # we share control files:
-        if self._hashcache.needs_write and self._control_files._lock_count==3:
-            self._hashcache.write()
+        if self._control_files._lock_count == 3:
+            # _inventory_is_modified is always False during a read lock.
+            if self._inventory_is_modified:
+                self.flush()
+            if self._hashcache.needs_write:
+                self._hashcache.write()
         # reverse order of locking.
         try:
             return self._control_files.unlock()
@@ -1804,8 +1870,12 @@
         return _mod_conflicts.ConflictList.from_stanzas(RioReader(confile))
 
     def unlock(self):
-        if self._hashcache.needs_write and self._control_files._lock_count==1:
-            self._hashcache.write()
+        if self._control_files._lock_count == 1:
+            # _inventory_is_modified is always False during a read lock.
+            if self._inventory_is_modified:
+                self.flush()
+            if self._hashcache.needs_write:
+                self._hashcache.write()
         # reverse order of locking.
         try:
             return self._control_files.unlock()
@@ -1957,9 +2027,10 @@
                          _internal=True,
                          _format=self,
                          _bzrdir=a_bzrdir)
-        wt._write_inventory(inv)
-        wt.set_root_id(inv.root.file_id)
         basis_tree = branch.repository.revision_tree(revision)
+        if basis_tree.inventory.root is not None:
+            wt.set_root_id(basis_tree.inventory.root.file_id)
+        # set the parent list and cache the basis tree.
         wt.set_parent_trees([(revision, basis_tree)])
         transform.build_tree(basis_tree, wt)
         return wt
@@ -2029,7 +2100,7 @@
         branch = a_bzrdir.open_branch()
         if revision_id is None:
             revision_id = branch.last_revision()
-        inv = Inventory() 
+        inv = Inventory(root_id=gen_root_id())
         wt = WorkingTree3(a_bzrdir.root_transport.local_abspath('.'),
                          branch,
                          inv,
@@ -2039,17 +2110,20 @@
                          _control_files=control_files)
         wt.lock_tree_write()
         try:
-            wt._write_inventory(inv)
-            wt.set_root_id(inv.root.file_id)
             basis_tree = branch.repository.revision_tree(revision_id)
+            # only set an explicit root id if there is one to set.
+            if basis_tree.inventory.root is not None:
+                wt.set_root_id(basis_tree.inventory.root.file_id)
             if revision_id == NULL_REVISION:
                 wt.set_parent_trees([])
             else:
                 wt.set_parent_trees([(revision_id, basis_tree)])
             transform.build_tree(basis_tree, wt)
         finally:
+            # Unlock in this order so that the unlock-triggers-flush in
+            # WorkingTree is given a chance to fire.
+            control_files.unlock()
             wt.unlock()
-            control_files.unlock()
         return wt
 
     def __init__(self):

=== modified file 'bzrlib/xml4.py'
--- bzrlib/xml4.py	2006-09-08 18:46:29 +0000
+++ bzrlib/xml4.py	2006-10-05 05:37:25 +0000
@@ -1,3 +1,5 @@
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -12,7 +14,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-
 from bzrlib.xml_serializer import ElementTree, SubElement, Element, Serializer
 from bzrlib.inventory import ROOT_ID, Inventory, InventoryEntry
 import bzrlib.inventory as inventory
@@ -20,10 +21,6 @@
 from bzrlib.errors import BzrError
 
 
-
-
-
-
 class _Serializer_v4(Serializer):
     """Version 0.0.4 serializer
 

=== modified file 'bzrlib/xml6.py'
--- bzrlib/xml6.py	2006-08-24 03:35:48 +0000
+++ bzrlib/xml6.py	2006-10-05 05:37:25 +0000
@@ -1,3 +1,19 @@
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 from bzrlib import cache_utf8, inventory, errors, xml5
 
 

=== modified file 'bzrlib/xml_serializer.py'
--- bzrlib/xml_serializer.py	2006-09-28 05:43:24 +0000
+++ bzrlib/xml_serializer.py	2006-10-05 05:37:25 +0000
@@ -1,4 +1,4 @@
-# -*- coding: UTF-8 -*-
+# Copyright (C) 2005, 2006 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'tools/win32/bzr.iss.cog'
--- tools/win32/bzr.iss.cog	2006-07-30 16:43:12 +0000
+++ tools/win32/bzr.iss.cog	2006-10-14 08:51:07 +0000
@@ -33,7 +33,7 @@
 SourceDir="..\..\win32_bzr.exe"
 
 SetupIconFile="..\bzr.ico"
-LicenseFile="..\COPYING.txt"
+InfoBeforeFile="..\tools\win32\info.txt"
 
 VersionInfoCompany="Canonical Ltd."
 VersionInfoCopyright="Canonical Ltd., 2005-2006"

=== added file 'tools/win32/info.txt'
--- tools/win32/info.txt	1970-01-01 00:00:00 +0000
+++ tools/win32/info.txt	2006-10-14 08:51:07 +0000
@@ -0,0 +1,7 @@
+
+Bazaar is free software; you can redistribute and/or modify it under
+the terms of the GNU General Public License version 2. 
+
+See: http://www.gnu.org/copyleft/gpl.html
+
+Managing source code in Bazaar does not make it subject to the GPL.

